@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractDocElement.php,v 1.10 2007/11/30 01:18:41 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -57,9 +56,9 @@ if (interface_exists('PHP_CodeSniffer_CommentParser_DocElement', true) === false
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_CommentParser_AbstractDocElement implements PHP_CodeSniffer_CommentParser_DocElement
@@ -127,9 +126,15 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractDocElement implements PHP_C
      * @throws Exception If $previousElement in not a DocElement or if
      *                   getSubElements() does not return an array.
      */
-    public function __construct($previousElement, array $tokens, $tag, PHP_CodeSniffer_File $phpcsFile)
-    {
-        if ($previousElement !== null && ($previousElement instanceof PHP_CodeSniffer_CommentParser_DocElement) === false) {
+    public function __construct(
+        $previousElement,
+        array $tokens,
+        $tag,
+        PHP_CodeSniffer_File $phpcsFile
+    ) {
+        if ($previousElement !== null
+            && ($previousElement instanceof PHP_CodeSniffer_CommentParser_DocElement) === false
+        ) {
             $error = '$previousElement must be an instance of DocElement';
             throw new Exception($error);
         }
@@ -180,7 +185,12 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractDocElement implements PHP_C
         $lastElementName = $subElements[($numSubElements - 1)];
 
         // Process the last element in this tag.
-        $this->processSubElement($lastElementName, $lastElement, $lastElementWhitespace);
+        $this->processSubElement(
+            $lastElementName,
+            $lastElement,
+            $lastElementWhitespace
+        );
+
         $this->afterWhitespace = $whitespace;
 
     }//end __construct()
@@ -278,6 +288,18 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractDocElement implements PHP_C
     }//end getRawContent()
 
 
+    /**
+     * Returns the comment tokens.
+     *
+     * @return array
+     */
+    public function getTokens()
+    {
+        return $this->tokens;
+
+    }//end getTokens()
+
+
     /**
      * Returns the line in which this element first occured.
      *
@@ -319,7 +341,11 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractDocElement implements PHP_C
      * @return void
      * @see getSubElements()
      */
-    abstract protected function processSubElement($name, $content, $whitespaceBefore);
+    abstract protected function processSubElement(
+        $name,
+        $content,
+        $whitespaceBefore
+    );
 
 
 }//end class
