@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractParser.php,v 1.19 2008/01/12 08:45:13 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -62,9 +61,9 @@ if (class_exists('PHP_CodeSniffer_CommentParser_ParserException', true) === fals
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_CommentParser_AbstractParser
@@ -101,6 +100,13 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected $words = array();
 
+    /**
+     * An array of all tags found in the comment.
+     *
+     * @var array(string)
+     */
+    protected $foundTags = array();
+
     /**
      * The previous doc element that was processed.
      *
@@ -215,7 +221,7 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
     private function _parse($comment)
     {
         // Firstly, remove the comment tags and any stars from the left side.
-        $lines = split($this->phpcsFile->eolChar, $comment);
+        $lines = explode($this->phpcsFile->eolChar, $comment);
         foreach ($lines as &$line) {
             $line = trim($line);
 
@@ -231,10 +237,16 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
                 // Add the words to the stack, preserving newlines. Other parsers
                 // might be interested in the spaces between words, so tokenize
                 // spaces as well as separate tokens.
-                $flags       = (PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
-                $words       = preg_split('|(\s+)|', $line.$this->phpcsFile->eolChar, -1, $flags);
+                $flags = (PREG_SPLIT_DELIM_CAPTURE | PREG_SPLIT_NO_EMPTY);
+                $words = preg_split(
+                    '|(\s+)|',
+                    $line.$this->phpcsFile->eolChar,
+                    -1,
+                    $flags
+                );
+
                 $this->words = array_merge($this->words, $words);
-            }
+            }//end if
         }//end foreach
 
         $this->_parseWords();
@@ -255,31 +267,36 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
     {
         $allowedTags     = (self::$_tags + $this->getAllowedTags());
         $allowedTagNames = array_keys($allowedTags);
-        $foundTags       = array();
         $prevTagPos      = false;
         $wordWasEmpty    = true;
 
         foreach ($this->words as $wordPos => $word) {
-
             if (trim($word) !== '') {
                 $wordWasEmpty = false;
             }
 
             if ($word{0} === '@') {
-
                 $tag = substr($word, 1);
 
                 // Filter out @ tags in the comment description.
                 // A real comment tag should have whitespace and a newline before it.
-                if (isset($this->words[($wordPos - 1)]) === false || trim($this->words[($wordPos - 1)]) !== '') {
+                if (isset($this->words[($wordPos - 1)]) === false
+                    || trim($this->words[($wordPos - 1)]) !== ''
+                ) {
                     continue;
                 }
 
-                if (isset($this->words[($wordPos - 2)]) === false || $this->words[($wordPos - 2)] !== $this->phpcsFile->eolChar) {
+                if (isset($this->words[($wordPos - 2)]) === false
+                    || $this->words[($wordPos - 2)] !== $this->phpcsFile->eolChar
+                ) {
                     continue;
                 }
 
-                $foundTags[] = $tag;
+                $this->foundTags[] = array(
+                                      'tag'  => $tag,
+                                      'line' => $this->getLine($wordPos),
+                                      'pos'  => $wordPos,
+                                     );
 
                 if ($prevTagPos !== false) {
                     // There was a tag before this so let's process it.
@@ -318,11 +335,10 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
                         $this->unknown[] = array(
                                             'tag'  => $tag,
                                             'line' => $this->getLine($wordPos),
+                                            'pos'  => $wordPos,
                                            );
                     }
-
                 }//end if
-
             }//end if
         }//end foreach
 
@@ -333,10 +349,32 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
                 $this->parseTag('comment', 0, count($this->words));
             } else {
                 // Process the last tag element.
-                $prevTag = substr($this->words[$prevTagPos], 1);
-                $this->parseTag($prevTag, $prevTagPos, count($this->words));
-            }
-        }
+                $prevTag  = substr($this->words[$prevTagPos], 1);
+                $numWords = count($this->words);
+                $endPos   = $numWords;
+
+                if ($prevTag === 'package' || $prevTag === 'subpackage') {
+                    // These are single-word tags, so anything after a newline
+                    // is really a comment.
+                    for ($endPos = $prevTagPos; $endPos < $numWords; $endPos++) {
+                        if (strpos($this->words[$endPos], $this->phpcsFile->eolChar) !== false) {
+                            break;
+                        }
+                    }
+                }
+
+                $this->parseTag($prevTag, $prevTagPos, $endPos);
+
+                if ($endPos !== $numWords) {
+                    // Process the final comment, if it is not empty.
+                    $tokens  = array_slice($this->words, ($endPos + 1), $numWords);
+                    $content = implode('', $tokens);
+                    if (trim($content) !== '') {
+                        $this->parseTag('comment', ($endPos + 1), $numWords);
+                    }
+                }
+            }//end if
+        }//end if
 
     }//end _parseWords()
 
@@ -370,7 +408,13 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected function parseSee($tokens)
     {
-        $see          = new PHP_CodeSniffer_CommentParser_SingleElement($this->previousElement, $tokens, 'see', $this->phpcsFile);
+        $see = new PHP_CodeSniffer_CommentParser_SingleElement(
+            $this->previousElement,
+            $tokens,
+            'see',
+            $this->phpcsFile
+        );
+
         $this->sees[] = $see;
         return $see;
 
@@ -386,7 +430,12 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected function parseComment($tokens)
     {
-        $this->comment = new PHP_CodeSniffer_CommentParser_CommentElement($this->previousElement, $tokens, $this->phpcsFile);
+        $this->comment = new PHP_CodeSniffer_CommentParser_CommentElement(
+            $this->previousElement,
+            $tokens,
+            $this->phpcsFile
+        );
+
         return $this->comment;
 
     }//end parseComment()
@@ -401,7 +450,13 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected function parseDeprecated($tokens)
     {
-        $this->deprecated = new PHP_CodeSniffer_CommentParser_SingleElement($this->previousElement, $tokens, 'deprecated', $this->phpcsFile);
+        $this->deprecated = new PHP_CodeSniffer_CommentParser_SingleElement(
+            $this->previousElement,
+            $tokens,
+            'deprecated',
+            $this->phpcsFile
+        );
+
         return $this->deprecated;
 
     }//end parseDeprecated()
@@ -416,7 +471,13 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected function parseSince($tokens)
     {
-        $this->since = new PHP_CodeSniffer_CommentParser_SingleElement($this->previousElement, $tokens, 'since', $this->phpcsFile);
+        $this->since = new PHP_CodeSniffer_CommentParser_SingleElement(
+            $this->previousElement,
+            $tokens,
+            'since',
+            $this->phpcsFile
+        );
+
         return $this->since;
 
     }//end parseSince()
@@ -431,7 +492,13 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
      */
     protected function parseLink($tokens)
     {
-        $link          = new PHP_CodeSniffer_CommentParser_SingleElement($this->previousElement, $tokens, 'link', $this->phpcsFile);
+        $link = new PHP_CodeSniffer_CommentParser_SingleElement(
+            $this->previousElement,
+            $tokens,
+            'link',
+            $this->phpcsFile
+        );
+
         $this->links[] = $link;
         return $link;
 
@@ -462,6 +529,30 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
     }//end getComment()
 
 
+    /**
+     * Returns the word list.
+     *
+     * @return array
+     */
+    public function getWords()
+    {
+        return $this->words;
+
+    }//end getWords()
+
+
+    /**
+     * Returns the list of found tags.
+     *
+     * @return array
+     */
+    public function getTags()
+    {
+        return $this->foundTags;
+
+    }//end getTags()
+
+
     /**
      * Returns the link elements found in this comment.
      *
@@ -532,12 +623,19 @@ abstract class PHP_CodeSniffer_CommentParser_AbstractParser
 
             $this->previousElement = $this->$method($tokens);
         } else {
-            $this->previousElement = new PHP_CodeSniffer_CommentParser_SingleElement($this->previousElement, $tokens, $tag, $this->phpcsFile);
+            $this->previousElement = new PHP_CodeSniffer_CommentParser_SingleElement(
+                $this->previousElement,
+                $tokens,
+                $tag,
+                $this->phpcsFile
+            );
         }
 
         $this->orders[] = $tag;
 
-        if ($this->previousElement === null || ($this->previousElement instanceof PHP_CodeSniffer_CommentParser_DocElement) === false) {
+        if ($this->previousElement === null
+            || ($this->previousElement instanceof PHP_CodeSniffer_CommentParser_DocElement) === false
+        ) {
             throw new Exception('Parse method must return a DocElement');
         }
 
