@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: FunctionCommentParser.php,v 1.8 2007/11/30 01:18:41 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -41,9 +40,9 @@ if (class_exists('PHP_CodeSniffer_CommentParser_SingleElement', true) === false)
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_CommentParser_FunctionCommentParser extends PHP_CodeSniffer_CommentParser_AbstractParser
@@ -93,7 +92,12 @@ class PHP_CodeSniffer_CommentParser_FunctionCommentParser extends PHP_CodeSniffe
      */
     protected function parseParam($tokens)
     {
-        $param           = new PHP_CodeSniffer_CommentParser_ParameterElement($this->previousElement, $tokens, $this->phpcsFile);
+        $param = new PHP_CodeSniffer_CommentParser_ParameterElement(
+            $this->previousElement,
+            $tokens,
+            $this->phpcsFile
+        );
+
         $this->_params[] = $param;
         return $param;
 
@@ -109,7 +113,13 @@ class PHP_CodeSniffer_CommentParser_FunctionCommentParser extends PHP_CodeSniffe
      */
     protected function parseReturn($tokens)
     {
-        $return        = new PHP_CodeSniffer_CommentParser_PairElement($this->previousElement, $tokens, 'return', $this->phpcsFile);
+        $return = new PHP_CodeSniffer_CommentParser_PairElement(
+            $this->previousElement,
+            $tokens,
+            'return',
+            $this->phpcsFile
+        );
+
         $this->_return = $return;
         return $return;
 
@@ -125,7 +135,13 @@ class PHP_CodeSniffer_CommentParser_FunctionCommentParser extends PHP_CodeSniffe
      */
     protected function parseThrows($tokens)
     {
-        $throws          = new PHP_CodeSniffer_CommentParser_PairElement($this->previousElement, $tokens, 'throws', $this->phpcsFile);
+        $throws = new PHP_CodeSniffer_CommentParser_PairElement(
+            $this->previousElement,
+            $tokens,
+            'throws',
+            $this->phpcsFile
+        );
+
         $this->_throws[] = $throws;
         return $throws;
 
