@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: SingleElement.php,v 1.12 2008/02/01 03:19:53 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -29,9 +28,9 @@ if (class_exists('PHP_CodeSniffer_CommentParser_AbstractDocElement', true) === f
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_CommentParser_SingleElement extends PHP_CodeSniffer_CommentParser_AbstractDocElement
@@ -70,8 +69,12 @@ class PHP_CodeSniffer_CommentParser_SingleElement extends PHP_CodeSniffer_Commen
      *                                                                  this element
      *                                                                  is in.
      */
-    public function __construct($previousElement, $tokens, $tag, PHP_CodeSniffer_File $phpcsFile)
-    {
+    public function __construct(
+        $previousElement,
+        $tokens,
+        $tag,
+        PHP_CodeSniffer_File $phpcsFile
+    ) {
         parent::__construct($previousElement, $tokens, $tag, $phpcsFile);
 
     }//end __construct()
@@ -145,12 +148,19 @@ class PHP_CodeSniffer_CommentParser_SingleElement extends PHP_CodeSniffer_Commen
      *
      * @return void
      */
-    public function process(PHP_CodeSniffer_File $phpcsFile, $commentStart, $docBlock)
-    {
+    public function process(
+        PHP_CodeSniffer_File $phpcsFile,
+        $commentStart,
+        $docBlock
+    ) {
         if ($this->content === '') {
             $errorPos = ($commentStart + $this->getLine());
-            $error    = "Content missing for $this->tag tag in $docBlock comment";
-            $phpcsFile->addError($error, $errorPos);
+            $error    = 'Content missing for %s tag in %s comment';
+            $data     = array(
+                         $this->tag,
+                         $docBlock,
+                        );
+            $phpcsFile->addError($error, $errorPos, 'EmptyTagContent', $data);
         }
 
     }//end process()
