@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: Generator.php,v 1.3 2007/12/21 02:54:45 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_DocGenerators_Generator
@@ -137,11 +136,14 @@ class PHP_CodeSniffer_DocGenerators_Generator
             $standardDir = $this->_standard;
             $standard    = basename($this->_standard);
         } else {
-            $standardDir = realpath(dirname(__FILE__).'/../Standards/'.$this->_standard);
-            $standard    = $this->_standard;
+            $standardDir
+                = realpath(dirname(__FILE__).'/../Standards/'.$this->_standard);
+
+            $standard = $this->_standard;
         }
 
-        $sniffs = PHP_CodeSniffer::getSniffFiles($standardDir, $standard);
+        $phpcs = new PHP_CodeSniffer();
+        $sniffs = $phpcs->getSniffFiles($standardDir, $standard);
 
         $standardFiles = array();
         foreach ($sniffs as $sniff) {
@@ -155,13 +157,17 @@ class PHP_CodeSniffer_DocGenerators_Generator
                 }
             }
 
-            $standardFile = str_replace(DIRECTORY_SEPARATOR.'Sniffs'.DIRECTORY_SEPARATOR, DIRECTORY_SEPARATOR.'Docs'.DIRECTORY_SEPARATOR, $sniff);
+            $standardFile = str_replace(
+                DIRECTORY_SEPARATOR.'Sniffs'.DIRECTORY_SEPARATOR,
+                DIRECTORY_SEPARATOR.'Docs'.DIRECTORY_SEPARATOR,
+                $sniff
+            );
             $standardFile = str_replace('Sniff.php', 'Standard.xml', $standardFile);
 
             if (is_file($standardFile) === true) {
                 $standardFiles[] = $standardFile;
             }
-        }
+        }//end foreach
 
         return $standardFiles;
 
