@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractPatternSniff.php,v 1.23 2008/06/13 02:25:39 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -28,14 +27,21 @@ if (class_exists('PHP_CodeSniffer_Standards_IncorrectPatternException', true) ==
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * The current file being checked.
+     *
+     * @var string
+     */
+    protected $currFile = '';
+
     /**
      * The parsed patterns array.
      *
@@ -44,7 +50,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
     private $_parsedPatterns = array();
 
     /**
-     * Tokens that wish this sniff wishes to process outside of the patterns.
+     * Tokens that this sniff wishes to process outside of the patterns.
      *
      * @var array(int)
      * @see registerSupplementary()
@@ -95,11 +101,10 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $patterns    = $this->getPatterns();
 
         foreach ($patterns as $pattern) {
-
             $parsedPattern = $this->_parse($pattern);
 
-            // Find a token position in the pattern that we can use for a listener
-            // token.
+            // Find a token position in the pattern that we can use
+            // for a listener token.
             $pos           = $this->_getListenerTokenPos($parsedPattern);
             $tokenType     = $parsedPattern[$pos]['token'];
             $listenTypes[] = $tokenType;
@@ -197,6 +202,13 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      */
     public final function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
+        $file = $phpcsFile->getFilename();
+        if ($this->currFile !== $file) {
+            // We have changed files, so clean up.
+            $this->_errorPos = array();
+            $this->currFile  = $file;
+        }
+
         $tokens = $phpcsFile->getTokens();
 
         if (in_array($tokens[$stackPtr]['code'], $this->_supplementaryTokens) === true) {
@@ -216,9 +228,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         // Loop over each pattern that is listening to the current token type
         // that we are processing.
         foreach ($this->_parsedPatterns[$type] as $patternInfo) {
-
             // If processPattern returns false, then the pattern that we are
-            // checking the code with must not be design to check that code.
+            // checking the code with must not be designed to check that code.
             $errors = $this->processPattern($patternInfo, $phpcsFile, $stackPtr);
             if ($errors === false) {
                 // The pattern didn't match.
@@ -257,8 +268,11 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
      *
      * @return array(errors)
      */
-    protected function processPattern($patternInfo, PHP_CodeSniffer_File $phpcsFile, $stackPtr)
-    {
+    protected function processPattern(
+        $patternInfo,
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    ) {
         $tokens      = $phpcsFile->getTokens();
         $pattern     = $patternInfo['pattern'];
         $patternCode = $patternInfo['pattern_code'];
@@ -266,9 +280,9 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $found       = '';
 
         $ignoreTokens = array(T_WHITESPACE);
-
         if ($this->_ignoreComments === true) {
-            $ignoreTokens = array_merge($ignoreTokens, PHP_CodeSniffer_Tokens::$commentTokens);
+            $ignoreTokens
+                = array_merge($ignoreTokens, PHP_CodeSniffer_Tokens::$commentTokens);
         }
 
         $origStackPtr = $stackPtr;
@@ -278,50 +292,53 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
             $stackPtr--;
 
             for ($i = ($patternInfo['listen_pos'] - 1); $i >= 0; $i--) {
-
                 if ($pattern[$i]['type'] === 'token') {
-
                     if ($pattern[$i]['token'] === T_WHITESPACE) {
-
                         if ($tokens[$stackPtr]['code'] === T_WHITESPACE) {
                             $found = $tokens[$stackPtr]['content'].$found;
                         }
 
                         // Only check the size of the whitespace if this is not
-                        // not the first token. We don't care about the size of
+                        // the first token. We don't care about the size of
                         // leading whitespace, just that there is some.
                         if ($i !== 0) {
                             if ($tokens[$stackPtr]['content'] !== $pattern[$i]['value']) {
                                 $hasError = true;
                             }
                         }
-
                     } else {
-
                         // Check to see if this important token is the same as the
                         // previous important token in the pattern. If it is not,
                         // then the pattern cannot be for this piece of code.
-                        $prev = $phpcsFile->findPrevious($ignoreTokens, $stackPtr, null, true);
-                        if ($prev === false || $tokens[$prev]['code'] !== $pattern[$i]['token']) {
+                        $prev = $phpcsFile->findPrevious(
+                            $ignoreTokens,
+                            $stackPtr,
+                            null,
+                            true
+                        );
+
+                        if ($prev === false
+                            || $tokens[$prev]['code'] !== $pattern[$i]['token']
+                        ) {
                             return false;
                         }
 
                         // If we skipped past some whitespace tokens, then add them
                         // to the found string.
-                        if (($stackPtr - $prev) > 1) {
-                            for ($j = ($stackPtr - 1); $j > $prev; $j--) {
-                                $found = $tokens[$j]['content'].$found;
-                            }
-                        }
+                        $tokenContent = $phpcsFile->getTokensAsString(
+                            ($prev + 1),
+                            ($stackPtr - $prev - 1)
+                        );
 
-                        $found = $tokens[$prev]['content'].$found;
+                        $found = $tokens[$prev]['content'].$tokenContent.$found;
 
-                        if (isset($pattern[($i - 1)]) === true && $pattern[($i - 1)]['type'] === 'skip') {
+                        if (isset($pattern[($i - 1)]) === true
+                            && $pattern[($i - 1)]['type'] === 'skip'
+                        ) {
                             $stackPtr = $prev;
                         } else {
                             $stackPtr = ($prev - 1);
                         }
-
                     }//end if
                 } else if ($pattern[$i]['type'] === 'skip') {
                     // Skip to next piece of relevant code.
@@ -332,7 +349,13 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     }
 
                     // Find the previous opener.
-                    $next = $phpcsFile->findPrevious($ignoreTokens, $stackPtr, null, true);
+                    $next = $phpcsFile->findPrevious(
+                        $ignoreTokens,
+                        $stackPtr,
+                        null,
+                        true
+                    );
+
                     if ($next === false || isset($tokens[$next][$to]) === false) {
                         // If there was not opener, then we must be
                         // using the wrong pattern.
@@ -352,7 +375,56 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 } else if ($pattern[$i]['type'] === 'string') {
                     $found = 'abc';
                 } else if ($pattern[$i]['type'] === 'newline') {
-                    $found = 'EOL';
+                    if ($this->_ignoreComments === true
+                        && in_array($tokens[$stackPtr]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true
+                    ) {
+                        $startComment = $phpcsFile->findPrevious(
+                            PHP_CodeSniffer_Tokens::$commentTokens,
+                            ($stackPtr - 1),
+                            null,
+                            true
+                        );
+
+                        if ($tokens[$startComment]['line'] !== $tokens[($startComment + 1)]['line']) {
+                            $startComment++;
+                        }
+
+                        $tokenContent = $phpcsFile->getTokensAsString(
+                            $startComment,
+                            ($stackPtr - $startComment + 1)
+                        );
+
+                        $found    = $tokenContent.$found;
+                        $stackPtr = ($startComment - 1);
+                    }
+
+                    if ($tokens[$stackPtr]['code'] === T_WHITESPACE) {
+                        if ($tokens[$stackPtr]['content'] !== $phpcsFile->eolChar) {
+                            $found = $tokens[$stackPtr]['content'].$found;
+
+                            // This may just be an indent that comes after a newline
+                            // so check the token before to make sure. If it is a newline, we
+                            // can ignore the error here.
+                            if ($tokens[($stackPtr - 1)]['content'] !== $phpcsFile->eolChar) {
+                                $hasError = true;
+                            } else {
+                                $stackPtr--;
+                            }
+                        } else {
+                            $found = 'EOL'.$found;
+                        }
+                    } else {
+                        $found    = $tokens[$stackPtr]['content'].$found;
+                        $hasError = true;
+                    }
+
+                    if ($hasError === false && $pattern[($i - 1)]['type'] !== 'newline') {
+                        // Make sure they only have 1 newline.
+                        $prev = $phpcsFile->findPrevious($ignoreTokens, ($stackPtr - 1), null, true);
+                        if ($prev !== false && $tokens[$prev]['line'] !== $tokens[$stackPtr]['line']) {
+                            $hasError = true;
+                        }
+                    }
                 }//end if
             }//end for
         }//end if
@@ -362,11 +434,8 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         $patternLen        = count($pattern);
 
         for ($i = $patternInfo['listen_pos']; $i < $patternLen; $i++) {
-
             if ($pattern[$i]['type'] === 'token') {
-
                 if ($pattern[$i]['token'] === T_WHITESPACE) {
-
                     if ($this->_ignoreComments === true) {
                         // If we are ignoring comments, check to see if this current
                         // token is a comment. If so skip it.
@@ -390,8 +459,18 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                             $tokenContent = $tokens[$stackPtr]['content'];
                         } else {
                             // Get all the whitespace to the next token.
-                            $next              = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, $stackPtr, null, true);
-                            $tokenContent      = $phpcsFile->getTokensAsString($stackPtr, ($next - $stackPtr));
+                            $next = $phpcsFile->findNext(
+                                PHP_CodeSniffer_Tokens::$emptyTokens,
+                                $stackPtr,
+                                null,
+                                true
+                            );
+
+                            $tokenContent = $phpcsFile->getTokensAsString(
+                                $stackPtr,
+                                ($next - $stackPtr)
+                            );
+
                             $lastAddedStackPtr = $stackPtr;
                             $stackPtr          = $next;
                         }
@@ -406,7 +485,9 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                         }
                     }//end if
 
-                    if (isset($pattern[($i + 1)]) === true && $pattern[($i + 1)]['type'] === 'skip') {
+                    if (isset($pattern[($i + 1)]) === true
+                        && $pattern[($i + 1)]['type'] === 'skip'
+                    ) {
                         // The next token is a skip token, so we just need to make
                         // sure the whitespace we found has *at least* the
                         // whitespace required.
@@ -418,16 +499,48 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                             $hasError = true;
                         }
                     }
-
                 } else {
                     // Check to see if this important token is the same as the
                     // next important token in the pattern. If it is not, then
                     // the pattern cannot be for this piece of code.
-                    $next = $phpcsFile->findNext($ignoreTokens, $stackPtr, null, true);
-                    if ($next === false || $tokens[$next]['code'] !== $pattern[$i]['token']) {
+                    $next = $phpcsFile->findNext(
+                        $ignoreTokens,
+                        $stackPtr,
+                        null,
+                        true
+                    );
+
+                    if ($next === false
+                        || $tokens[$next]['code'] !== $pattern[$i]['token']
+                    ) {
+                        // The next important token did not match the pattern.
                         return false;
                     }
 
+                    if ($lastAddedStackPtr !== null) {
+                        if (($tokens[$next]['code'] === T_OPEN_CURLY_BRACKET
+                            || $tokens[$next]['code'] === T_CLOSE_CURLY_BRACKET)
+                            && isset($tokens[$next]['scope_condition']) === true
+                            && $tokens[$next]['scope_condition'] > $lastAddedStackPtr
+                        ) {
+                            // This is a brace, but the owner of it is after the current
+                            // token, which means it does not belong to any token in
+                            // our pattern. This means the pattern is not for us.
+                            return false;
+                        }
+
+                        if (($tokens[$next]['code'] === T_OPEN_PARENTHESIS
+                            || $tokens[$next]['code'] === T_CLOSE_PARENTHESIS)
+                            && isset($tokens[$next]['parenthesis_owner']) === true
+                            && $tokens[$next]['parenthesis_owner'] > $lastAddedStackPtr
+                        ) {
+                            // This is a bracket, but the owner of it is after the current
+                            // token, which means it does not belong to any token in
+                            // our pattern. This means the pattern is not for us.
+                            return false;
+                        }
+                    }//end if
+
                     // If we skipped past some whitespace tokens, then add them
                     // to the found string.
                     if (($next - $stackPtr) > 0) {
@@ -443,7 +556,10 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                         // whitespace or comment is not allowed. If we are
                         // ignoring comments, there needs to be at least one
                         // comment for this to be allowed.
-                        if ($this->_ignoreComments === false || ($this->_ignoreComments === true && $hasComment === false)) {
+                        if ($this->_ignoreComments === false
+                            || ($this->_ignoreComments === true
+                            && $hasComment === false)
+                        ) {
                             $hasError = true;
                         }
 
@@ -460,31 +576,54 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                         $lastAddedStackPtr = $next;
                     }
 
-                    if (isset($pattern[($i + 1)]) === true && $pattern[($i + 1)]['type'] === 'skip') {
+                    if (isset($pattern[($i + 1)]) === true
+                        && $pattern[($i + 1)]['type'] === 'skip'
+                    ) {
                         $stackPtr = $next;
                     } else {
                         $stackPtr = ($next + 1);
                     }
                 }//end if
-
             } else if ($pattern[$i]['type'] === 'skip') {
-                // Find the previous opener.
-                $next = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$blockOpeners, $stackPtr, null);
-                if ($next === false || isset($tokens[$next][$pattern[$i]['to']]) === false) {
-                    // If there was not opener, then we must
-                    // be using the wrong pattern.
-                    return false;
-                }
+                if ($pattern[$i]['to'] === 'unknown') {
+                    $next = $phpcsFile->findNext(
+                        $pattern[($i + 1)]['token'],
+                        $stackPtr
+                    );
 
-                $found .= '...';
-                if ($pattern[$i]['to'] === 'parenthesis_closer') {
-                    $found .= ')';
+                    if ($next === false) {
+                        // Couldn't find the next token, sowe we must
+                        // be using the wrong pattern.
+                        return false;
+                    }
+
+                    $found   .= '...';
+                    $stackPtr = $next;
                 } else {
-                    $found .= '}';
-                }
+                    // Find the previous opener.
+                    $next = $phpcsFile->findPrevious(
+                        PHP_CodeSniffer_Tokens::$blockOpeners,
+                        $stackPtr
+                    );
 
-                // Skip to the closing token.
-                $stackPtr = ($tokens[$next][$pattern[$i]['to']] + 1);
+                    if ($next === false
+                        || isset($tokens[$next][$pattern[$i]['to']]) === false
+                    ) {
+                        // If there was not opener, then we must
+                        // be using the wrong pattern.
+                        return false;
+                    }
+
+                    $found .= '...';
+                    if ($pattern[$i]['to'] === 'parenthesis_closer') {
+                        $found .= ')';
+                    } else {
+                        $found .= '}';
+                    }
+
+                    // Skip to the closing token.
+                    $stackPtr = ($tokens[$next][$pattern[$i]['to']] + 1);
+                }//end if
             } else if ($pattern[$i]['type'] === 'string') {
                 if ($tokens[$stackPtr]['code'] !== T_STRING) {
                     $hasError = true;
@@ -523,7 +662,13 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                     } else {
                         // Check that there were no significant tokens that we
                         // skipped over to find our newline character.
-                        $next = $phpcsFile->findNext($ignoreTokens, $stackPtr, null, true);
+                        $next = $phpcsFile->findNext(
+                            $ignoreTokens,
+                            $stackPtr,
+                            null,
+                            true
+                        );
+
                         if ($next < $newline) {
                             // We skipped a non-ignored token.
                             $hasError = true;
@@ -534,8 +679,12 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 }//end if
 
                 if ($stackPtr !== $lastAddedStackPtr) {
-                    $found            .= $phpcsFile->getTokensAsString($stackPtr, ($next - $stackPtr));
-                    $diff              = ($next - $stackPtr);
+                    $found .= $phpcsFile->getTokensAsString(
+                        $stackPtr,
+                        ($next - $stackPtr)
+                    );
+
+                    $diff = ($next - $stackPtr);
                     $lastAddedStackPtr = ($next - 1);
                 }
 
@@ -544,7 +693,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
         }//end for
 
         if ($hasError === true) {
-            $error                 = $this->prepareError($found, $patternCode);
+            $error = $this->prepareError($found, $patternCode);
             $errors[$origStackPtr] = $error;
         }
 
@@ -612,8 +761,10 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
       * @return void
       * @see registerSupplementary()
       */
-    protected function processSupplementary(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
-    {
+    protected function processSupplementary(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    ) {
          return;
 
     }//end processSupplementary()
@@ -647,8 +798,12 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 // to skip to.
                 $specialPattern = $this->_createSkipPattern($pattern, ($i - 1));
                 $lastToken      = ($i - $firstToken);
-                $firstToken     = ($i + 4);
-                $i              = ($i + 3);
+                $firstToken     = ($i + 3);
+                $i              = ($i + 2);
+
+                if ($specialPattern['to'] !== 'unknown') {
+                    $firstToken++;
+                }
             } else if (substr($pattern, $i, 3) === 'abc') {
                 $specialPattern = array('type' => 'string');
                 $lastToken      = ($i - $firstToken);
@@ -662,7 +817,6 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
             }
 
             if ($specialPattern !== false || $isLastChar === true) {
-
                 // If we are at the end of the string, don't worry about a limit.
                 if ($isLastChar === true) {
                     // Get the string from the end of the last skip pattern, if any,
@@ -671,19 +825,27 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
                 } else {
                     // Get the string from the end of the last special pattern,
                     // if any, to the start of this special pattern.
-                    $str = substr($pattern, $oldFirstToken, $lastToken);
+                    if ($lastToken === 0) {
+                        // Note that if the last special token was zero characters ago,
+                        // there will be nothing to process so we can skip this bit.
+                        // This happens if you have something like: EOL... in your pattern.
+                        $str = '';
+                    } else {
+                        $str = substr($pattern, $oldFirstToken, $lastToken);
+                    }
                 }
 
-                $tokenPatterns = $this->_createTokenPattern($str);
+                if ($str !== '') {
+                    $tokenPatterns = $this->_createTokenPattern($str);
+                    foreach ($tokenPatterns as $tokenPattern) {
+                        $patterns[] = $tokenPattern;
+                    }
+                }
 
                 // Make sure we don't skip the last token.
                 if ($isLastChar === false && $i === ($length - 1)) {
                     $i--;
                 }
-
-                foreach ($tokenPatterns as $tokenPattern) {
-                    $patterns[] = $tokenPattern;
-                }
             }//end if
 
             // Add the skip pattern *after* we have processed
@@ -692,7 +854,6 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
             if ($specialPattern !== false) {
                 $patterns[] = $specialPattern;
             }
-
         }//end for
 
         return $patterns;
@@ -714,13 +875,29 @@ abstract class PHP_CodeSniffer_Standards_AbstractPatternSniff implements PHP_Cod
     {
         $skip = array('type' => 'skip');
 
-        for ($from; $from >= 0; $from--) {
-            switch ($pattern[$from]) {
+        $nestedParenthesis = 0;
+        $nestedBraces      = 0;
+        for ($start = $from; $start >= 0; $start--) {
+            switch ($pattern[$start]) {
             case '(':
-                $skip['to'] = 'parenthesis_closer';
+                if ($nestedParenthesis === 0) {
+                    $skip['to'] = 'parenthesis_closer';
+                }
+
+                $nestedParenthesis--;
                 break;
             case '{':
-                $skip['to'] = 'scope_closer';
+                if ($nestedBraces === 0) {
+                    $skip['to'] = 'scope_closer';
+                }
+
+                $nestedBraces--;
+                break;
+            case '}':
+                $nestedBraces++;
+                break;
+            case ')':
+                $nestedParenthesis++;
                 break;
             }
 
