@@ -9,9 +9,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractScopeSniff.php,v 1.9 2008/02/27 00:05:18 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -40,9 +39,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeSniffer_Sniff
@@ -62,13 +61,6 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
      */
     private $_scopeTokens = array();
 
-    /**
-     * The position in the tokens array that opened the current scope.
-     *
-     * @var array()
-     */
-    protected $currScope = null;
-
     /**
      * True if this test should fire on tokens outside of the scope.
      *
@@ -89,25 +81,28 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
      *                               processTokenOutideScope method.
      *
      * @see PHP_CodeSniffer.getValidScopeTokeners()
-     * @throws PHP_CodeSniffer_Test_Exception If the specified tokens array is empty.
+     * @throws PHP_CodeSniffer_Exception If the specified tokens array is empty.
      */
-    public function __construct(array $scopeTokens, array $tokens, $listenOutside=false)
-    {
+    public function __construct(
+        array $scopeTokens,
+        array $tokens,
+        $listenOutside=false
+    ) {
         if (empty($scopeTokens) === true) {
             $error = 'The scope tokens list cannot be empty';
-            throw new PHP_CodeSniffer_Test_Exception($error);
+            throw new PHP_CodeSniffer_Exception($error);
         }
 
         if (empty($tokens) === true) {
             $error = 'The tokens list cannot be empty';
-            throw new PHP_CodeSniffer_Test_Exception($error);
+            throw new PHP_CodeSniffer_Exception($error);
         }
 
         $invalidScopeTokens = array_intersect($scopeTokens, $tokens);
         if (empty($invalidScopeTokens) === false) {
             $invalid = implode(', ', $invalidScopeTokens);
             $error   = "Scope tokens [$invalid] cant be in the tokens array";
-            throw new PHP_CodeSniffer_Test_Exception($error);
+            throw new PHP_CodeSniffer_Exception($error);
         }
 
         $this->_listenOutside = $listenOutside;
@@ -129,11 +124,7 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
      */
     public final function register()
     {
-        if ($this->_listenOutside === false) {
-            return $this->_scopeTokens;
-        } else {
-            return array_merge($this->_scopeTokens, $this->_tokens);
-        }
+        return $this->_tokens;
 
     }//end register()
 
@@ -152,23 +143,15 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
     {
         $tokens = $phpcsFile->getTokens();
 
-        if (in_array($tokens[$stackPtr]['code'], $this->_scopeTokens) === true) {
-            $this->currScope = $stackPtr;
-            $phpcsFile->addTokenListener($this, $this->_tokens);
-        } else if ($this->currScope !== null && isset($tokens[$this->currScope]['scope_closer']) === true && $stackPtr > $tokens[$this->currScope]['scope_closer']) {
-            $this->currScope = null;
-            if ($this->_listenOutside === true) {
-                // This is a token outside the current scope, so notify the
-                // extender as they wish to know about this.
-                $this->processTokenOutsideScope($phpcsFile, $stackPtr);
-            } else {
-                // Don't remove the listener if the extender wants to know about
-                // tokens that live outside the current scope.
-                $phpcsFile->removeTokenListener($this, $this->_tokens);
+        $foundScope = false;
+        foreach ($tokens[$stackPtr]['conditions'] as $scope => $code) {
+            if (in_array($code, $this->_scopeTokens) === true) {
+                $this->processTokenWithinScope($phpcsFile, $stackPtr, $scope);
+                $foundScope = true;
             }
-        } else if ($this->currScope !== null) {
-            $this->processTokenWithinScope($phpcsFile, $stackPtr, $this->currScope);
-        } else {
+        }
+
+        if ($this->_listenOutside === true && $foundScope === false) {
             $this->processTokenOutsideScope($phpcsFile, $stackPtr);
         }
 
@@ -188,7 +171,11 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
      *
      * @return void
      */
-    protected abstract function processTokenWithinScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr, $currScope);
+    protected abstract function processTokenWithinScope(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr,
+        $currScope
+    );
 
 
     /**
@@ -201,8 +188,10 @@ abstract class PHP_CodeSniffer_Standards_AbstractScopeSniff implements PHP_CodeS
      *
      * @return void
      */
-    protected function processTokenOutsideScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
-    {
+    protected function processTokenOutsideScope(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    ) {
         return;
 
     }//end processTokenOutsideScope()
