@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AbstractVariableSniff.php,v 1.14 2008/05/08 03:58:12 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -32,9 +31,9 @@ if (class_exists('PHP_CodeSniffer_Standards_AbstractScopeSniff', true) === false
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeSniffer_Standards_AbstractScopeSniff
@@ -67,18 +66,19 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      */
     public function __construct()
     {
-        $listen = array(
+        $scopes = array(
                    T_CLASS,
                    T_INTERFACE,
                   );
 
-        $scopes = array(
+        $listen = array(
                    T_FUNCTION,
                    T_VARIABLE,
                    T_DOUBLE_QUOTED_STRING,
+                   T_HEREDOC,
                   );
 
-        parent::__construct($listen, $scopes, true);
+        parent::__construct($scopes, $listen, true);
 
     }//end __construct()
 
@@ -93,8 +93,11 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      *
      * @return void
      */
-    protected final function processTokenWithinScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr, $currScope)
-    {
+    protected final function processTokenWithinScope(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr,
+        $currScope
+    ) {
         if ($this->currentFile !== $phpcsFile) {
             $this->currentFile   = $phpcsFile;
             $this->_functionOpen = false;
@@ -107,16 +110,20 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
             $this->_functionOpen = false;
         }
 
-        if ($tokens[$stackPtr]['code'] === T_FUNCTION && $this->_functionOpen === false) {
-
+        if ($tokens[$stackPtr]['code'] === T_FUNCTION
+            && $this->_functionOpen === false
+        ) {
             $this->_functionOpen = true;
 
             $methodProps = $phpcsFile->getMethodProperties($stackPtr);
 
             // If the function is abstract, or is in an interface,
             // then set the end of the function to it's closing semicolon.
-            if ($methodProps['is_abstract'] === true || $tokens[$currScope]['code'] === T_INTERFACE) {
-                $this->_endFunction = $phpcsFile->findNext(array(T_SEMICOLON), $stackPtr);
+            if ($methodProps['is_abstract'] === true
+                || $tokens[$currScope]['code'] === T_INTERFACE
+            ) {
+                $this->_endFunction
+                    = $phpcsFile->findNext(array(T_SEMICOLON), $stackPtr);
             } else {
                 if (isset($tokens[$stackPtr]['scope_closer']) === false) {
                     $error = 'Possible parse error: non-abstract method defined as abstract';
@@ -126,21 +133,24 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
 
                 $this->_endFunction = $tokens[$stackPtr]['scope_closer'];
             }
+        }
 
+        if ($tokens[$stackPtr]['code'] === T_DOUBLE_QUOTED_STRING
+            || $tokens[$stackPtr]['code'] === T_HEREDOC
+        ) {
+            // Check to see if this string has a variable in it.
+            $pattern = '|(?<!\\\\)(?:\\\\{2})*\${?[a-zA-Z0-9_]+}?|';
+            if (preg_match($pattern, $tokens[$stackPtr]['content']) !== 0) {
+                $this->processVariableInString($phpcsFile, $stackPtr);
+            }
+
+            return;
         }
 
         if ($this->_functionOpen === true) {
             if ($tokens[$stackPtr]['code'] === T_VARIABLE) {
                 $this->processVariable($phpcsFile, $stackPtr);
-            } else if ($tokens[$stackPtr]['code'] === T_DOUBLE_QUOTED_STRING) {
-                // Check to see if this string has a variable in it.
-                $pattern = '|[^\\\]\$[a-zA-Z0-9_]+|';
-                if (preg_match($pattern, $tokens[$stackPtr]['content']) !== 0) {
-                    $this->processVariableInString($phpcsFile, $stackPtr);
-                }
             }
-
-            return;
         } else {
             // What if we assign a member variable to another?
             // ie. private $_count = $this->_otherCount + 1;.
@@ -159,14 +169,22 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      *
      * @return void
      */
-    protected final function processTokenOutsideScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
-    {
+    protected final function processTokenOutsideScope(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    ) {
         $tokens = $phpcsFile->getTokens();
         // These variables are not member vars.
         if ($tokens[$stackPtr]['code'] === T_VARIABLE) {
             $this->processVariable($phpcsFile, $stackPtr);
-        } else {
-            $this->processVariableInString($phpcsFile, $stackPtr);
+        } else if ($tokens[$stackPtr]['code'] === T_DOUBLE_QUOTED_STRING
+            || $tokens[$stackPtr]['code'] === T_HEREDOC
+        ) {
+            // Check to see if this string has a variable in it.
+            $pattern = '|(?<!\\\\)(?:\\\\{2})*\${?[a-zA-Z0-9_]+}?|';
+            if (preg_match($pattern, $tokens[$stackPtr]['content']) !== 0) {
+                $this->processVariableInString($phpcsFile, $stackPtr);
+            }
         }
 
     }//end processTokenOutsideScope()
@@ -181,7 +199,10 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      *
      * @return void
      */
-    abstract protected function processMemberVar(PHP_CodeSniffer_File $phpcsFile, $stackPtr);
+    abstract protected function processMemberVar(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    );
 
 
     /**
@@ -193,14 +214,17 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      *
      * @return void
      */
-    abstract protected function processVariable(PHP_CodeSniffer_File $phpcsFile, $stackPtr);
+    abstract protected function processVariable(
+        PHP_CodeSniffer_File $phpcsFile,
+        $stackPtr
+    );
 
 
     /**
-     * Called to process variables found in duoble quoted strings.
+     * Called to process variables found in duoble quoted strings or heredocs.
      *
      * Note that there may be more than one variable in the string, which will
-     * result only in one call for the string.
+     * result only in one call for the string or one call per line for heredocs.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The PHP_CodeSniffer file where this
      *                                        token was found.
@@ -209,7 +233,11 @@ abstract class PHP_CodeSniffer_Standards_AbstractVariableSniff extends PHP_CodeS
      *
      * @return void
      */
-    abstract protected function processVariableInString(PHP_CodeSniffer_File $phpcsFile, $stackPtr);
+    abstract protected function processVariableInString(
+        PHP_CodeSniffer_File
+        $phpcsFile,
+        $stackPtr
+    );
 
 
 }//end class
