@@ -10,23 +10,21 @@
  * @author    Manuel Pichler <mapi@manuel-pichler.de>
  * @copyright 2007-2008 Manuel Pichler. All rights reserved.
  * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
- * @version   CVS: $Id: UselessOverridingMethodSniff.php,v 1.1 2008/02/06 02:38:36 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
 /**
- * Detects unnecessary final modifiers inside of final classes.
+ * Detects unnecessary overriden methods that simply call their parent.
  *
- * This rule is based on the PMD rule catalog. The Unnecessary Final Modifier
- * sniff detects the use of the final modifier inside of a final class which
- * is unnecessary.
+ * This rule is based on the PMD rule catalog. The Useless Overriding Method
+ * sniff detects the use of methods that only call their parent classes's method
+ * with the same name and arguments. These methods are not required.
  *
  * <code>
- * final class Foo
- * {
- *     public final function bar()
- *     {
- *     }
+ * class FooBar {
+ *   public function __construct($a, $b) {
+ *     parent::__construct($a, $b);
+ *   }
  * }
  * </code>
  *
@@ -35,7 +33,7 @@
  * @author    Manuel Pichler <mapi@manuel-pichler.de>
  * @copyright 2007-2008 Manuel Pichler. All rights reserved.
  * @license   http://www.opensource.org/licenses/bsd-license.php BSD License
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_CodeAnalysis_UselessOverridingMethodSniff implements PHP_CodeSniffer_Sniff
@@ -171,7 +169,7 @@ class Generic_Sniffs_CodeAnalysis_UselessOverridingMethodSniff implements PHP_Co
         $parameters = array_filter($parameters);
 
         if (count($parameters) === count($signature) && $parameters === $signature) {
-            $phpcsFile->addWarning('Useless method overriding detected', $stackPtr);
+            $phpcsFile->addWarning('Useless method overriding detected', $stackPtr, 'Found');
         }
 
     }//end process()
