@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: MultipleStatementAlignmentSniff.php,v 1.17 2008/02/21 05:21:12 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,9 +24,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_CodeSniffer_Sniff
@@ -48,10 +47,10 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
      *
      * @var bool
      */
-    protected $error = false;
+    public $error = false;
 
     /**
-     * The maximum amount of padding before the alignment is ignore.
+     * The maximum amount of padding before the alignment is ignored.
      *
      * If the amount of padding required to align this assignment with the
      * surrounding assignments exceeds this number, the assignment will be
@@ -59,7 +58,14 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
      *
      * @var int
      */
-    protected $maxPadding = 1000;
+    public $maxPadding = 1000;
+
+    /**
+     * If true, multi-line assignments are not checked.
+     *
+     * @var int
+     */
+    public $ignoreMultiLine = false;
 
 
     /**
@@ -78,8 +84,8 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
      * Processes this test, when one of its tokens is encountered.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
-     * @param int                  $stackPtr  The position of the current token in the
-     *                                        stack passed in $tokens.
+     * @param int                  $stackPtr  The position of the current token
+     *                                        in the stack passed in $tokens.
      *
      * @return void
      */
@@ -106,7 +112,11 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
         // end of the assignment so we can check assignment blocks correctly.
         $lineEnd = $phpcsFile->findNext(T_SEMICOLON, ($stackPtr + 1));
 
-        $nextAssign = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$assignmentTokens, ($lineEnd + 1));
+        $nextAssign = $phpcsFile->findNext(
+            PHP_CodeSniffer_Tokens::$assignmentTokens,
+            ($lineEnd + 1)
+        );
+
         if ($nextAssign !== false) {
             $isAssign = true;
             if ($tokens[$nextAssign]['line'] === ($tokens[$lineEnd]['line'] + 1)) {
@@ -136,10 +146,26 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
 
         while (($prevAssignment = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$assignmentTokens, ($prevAssignment - 1))) !== false) {
 
+            // We are not interested in double arrows as they assign values inside
+            // arrays and loops and do not use the same indentation rules.
+            if ($tokens[$prevAssignment]['code'] === T_DOUBLE_ARROW) {
+                continue;
+            }
+
             // The assignment's end token must be on the line directly
             // above the current one to be in the same assignment block.
             $lineEnd = $phpcsFile->findNext(T_SEMICOLON, ($prevAssignment + 1));
 
+            // And the end token must actually belong to this assignment.
+            $nextOpener = $phpcsFile->findNext(
+                PHP_CodeSniffer_Tokens::$scopeOpeners,
+                ($prevAssignment + 1)
+            );
+
+            if ($nextOpener !== false && $nextOpener < $lineEnd) {
+                break;
+            }
+
             if ($tokens[$lineEnd]['line'] !== ($lastLine - 1)) {
                 break;
             }
@@ -162,7 +188,12 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
         $maxVariableLength   = 0;
 
         foreach ($assignments as $assignment) {
-            $prev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($assignment - 1), null, true);
+            $prev = $phpcsFile->findPrevious(
+                PHP_CodeSniffer_Tokens::$emptyTokens,
+                ($assignment - 1),
+                null,
+                true
+            );
 
             $endColumn = $tokens[($prev + 1)]['column'];
 
@@ -174,10 +205,11 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
                 $maxAssignmentLength = strlen($tokens[$assignment]['content']);
             }
 
-            $assignmentData[$assignment] = array(
-                                            'variable_length'   => $endColumn,
-                                            'assignment_length' => strlen($tokens[$assignment]['content']),
-                                           );
+            $assignmentData[$assignment]
+                = array(
+                   'variable_length'   => $endColumn,
+                   'assignment_length' => strlen($tokens[$assignment]['content']),
+                  );
         }//end foreach
 
         foreach ($assignmentData as $assignment => $data) {
@@ -202,30 +234,64 @@ class Generic_Sniffs_Formatting_MultipleStatementAlignmentSniff implements PHP_C
             // Actual column takes into account the length of the assignment operator.
             $actualColumn = ($column + $maxAssignmentLength - strlen($tokens[$assignment]['content']));
             if ($tokens[$assignment]['column'] !== $actualColumn) {
-                $prev = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($assignment - 1), null, true);
+                $prev = $phpcsFile->findPrevious(
+                    PHP_CodeSniffer_Tokens::$emptyTokens,
+                    ($assignment - 1),
+                    null,
+                    true
+                );
 
                 $expected = ($actualColumn - $tokens[($prev + 1)]['column']);
-                $found    = ($tokens[$assignment]['column'] - $tokens[($prev + 1)]['column']);
+
+                if ($tokens[$assignment]['line'] !== $tokens[$prev]['line']) {
+                    // Instead of working out how many spaces there are
+                    // across new lines, the error message becomes more
+                    // generic below.
+                    $found = null;
+                } else {
+                    $found = ($tokens[$assignment]['column'] - $tokens[($prev + 1)]['column']);
+                }
 
                 // If the expected number of spaces for alignment exceeds the
-                // maxPadding rule, we can ignore this assignment.
+                // maxPadding rule, we just check for a single space as no
+                // alignment is required.
                 if ($expected > $this->maxPadding) {
+                    if ($found === 1) {
+                        continue;
+                    } else {
+                        $expected = 1;
+                    }
+                }
+
+                // Skip multi-line assignments if required.
+                if ($found === null && $this->ignoreMultiLine === true) {
                     continue;
                 }
 
                 $expected .= ($expected === 1) ? ' space' : ' spaces';
-                $found    .= ($found === 1) ? ' space' : ' spaces';
-
-                if (count($assignments) === 1) {
-                    $error = "Equals sign not aligned correctly; expected $expected but found $found";
+                if ($found === null) {
+                    $found = 'a new line';
                 } else {
-                    $error = "Equals sign not aligned with surrounding assignments; expected $expected but found $found";
+                    $found .= ($found === 1) ? ' space' : ' spaces';
                 }
 
-                if ($this->error === true) {
-                    $phpcsFile->addError($error, $assignment);
+                if (count($assignments) === 1) {
+                    $type  = 'Incorrect';
+                    $error = 'Equals sign not aligned correctly; expected %s but found %s';
                 } else {
-                    $phpcsFile->addWarning($error, $assignment);
+                    $type  = 'NotSame';
+                    $error = 'Equals sign not aligned with surrounding assignments; expected %s but found %s';
+                }
+
+                $errorData = array(
+                              $expected,
+                              $found,
+                             );
+
+                if ($this->error === true) {
+                    $phpcsFile->addError($error, $assignment, $type, $errorData);
+                } else {
+                    $phpcsFile->addWarning($error, $assignment, $type.'Warning', $errorData);
                 }
             }//end if
         }//end foreach
