@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: OpeningFunctionBraceKernighanRitchieSniff.php,v 1.5 2008/05/05 03:59:12 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff implements PHP_CodeSniffer_Sniff
@@ -74,7 +73,7 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff impleme
 
         if ($lineDifference > 0) {
             $error = 'Opening brace should be on the same line as the declaration';
-            $phpcsFile->addError($error, $openingBrace);
+            $phpcsFile->addError($error, $openingBrace, 'BraceOnNewLine');
             return;
         }
 
@@ -86,8 +85,9 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff impleme
         $columnDifference = ($braceColumn - $closerColumn);
 
         if ($columnDifference !== 2) {
-            $error = 'Expected 1 space between the closing parenthesis and the opening brace; found '.($columnDifference - 1).'.';
-            $phpcsFile->addError($error, $openingBrace);
+            $error = 'Expected 1 space between the closing parenthesis and the opening brace; found %s';
+            $data  = array(($columnDifference - 1));
+            $phpcsFile->addError($error, $openingBrace, 'SpaceBeforeBrace', $data);
             return;
         }
 
@@ -95,8 +95,9 @@ class Generic_Sniffs_Functions_OpeningFunctionBraceKernighanRitchieSniff impleme
         $spaceTokenPtr = ($tokens[$stackPtr]['parenthesis_closer'] + 1);
         $spaceContent  = $tokens[$spaceTokenPtr]['content'];
         if ($spaceContent !== ' ') {
-            $error = 'Expected a single space character between closing parenthesis and opening brace; found "'.$spaceContent.'".';
-            $phpcsFile->addError($error, $openingBrace);
+            $error = 'Expected a single space character between closing parenthesis and opening brace; found %s';
+            $data  = array($spaceContent);
+            $phpcsFile->addError($error, $openingBrace, 'SpaceBeforeBrace', $data);
             return;
         }
 
