@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: UpperCaseConstantNameSniff.php,v 1.10 2008/05/07 23:13:49 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_NamingConventions_UpperCaseConstantNameSniff implements PHP_CodeSniffer_Sniff
@@ -63,21 +62,32 @@ class Generic_Sniffs_NamingConventions_UpperCaseConstantNameSniff implements PHP
             return;
         }
 
+        // Special case for PHPUnit.
+        if ($constName === 'PHPUnit_MAIN_METHOD') {
+            return;
+        }
+
         // If the next non-whitespace token after this token
         // is not an opening parenthesis then it is not a function call.
-        $openBracket = $phpcsFile->findNext(array(T_WHITESPACE), ($stackPtr + 1), null, true);
+        $openBracket = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
         if ($tokens[$openBracket]['code'] !== T_OPEN_PARENTHESIS) {
-            $functionKeyword = $phpcsFile->findPrevious(array(T_WHITESPACE, T_COMMA, T_COMMENT, T_STRING), ($stackPtr - 1), null, true);
+            $functionKeyword = $phpcsFile->findPrevious(array(T_WHITESPACE, T_COMMA, T_COMMENT, T_STRING, T_NS_SEPARATOR), ($stackPtr - 1), null, true);
 
             $declarations = array(
                              T_FUNCTION,
                              T_CLASS,
                              T_INTERFACE,
+                             T_TRAIT,
                              T_IMPLEMENTS,
                              T_EXTENDS,
                              T_INSTANCEOF,
                              T_NEW,
+                             T_NAMESPACE,
+                             T_USE,
+                             T_AS,
+                             T_GOTO,
                             );
+
             if (in_array($tokens[$functionKeyword]['code'], $declarations) === true) {
                 // This is just a declaration; no constants here.
                 return;
@@ -86,42 +96,67 @@ class Generic_Sniffs_NamingConventions_UpperCaseConstantNameSniff implements PHP
             if ($tokens[$functionKeyword]['code'] === T_CONST) {
                 // This is a class constant.
                 if (strtoupper($constName) !== $constName) {
-                    $error = 'Class constants must be uppercase; expected '.strtoupper($constName)." but found $constName";
-                    $phpcsFile->addError($error, $stackPtr);
+                    $error = 'Class constants must be uppercase; expected %s but found %s';
+                    $data  = array(
+                              strtoupper($constName),
+                              $constName,
+                             );
+                    $phpcsFile->addError($error, $stackPtr, 'ClassConstantNotUpperCase', $data);
                 }
 
                 return;
             }
 
             // Is this a class name?
-            $nextPtr = $phpcsFile->findNext(array(T_WHITESPACE), ($stackPtr + 1), null, true);
+            $nextPtr = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
             if ($tokens[$nextPtr]['code'] === T_DOUBLE_COLON) {
                 return;
             }
 
-            // Is this a type hint?
-            if ($tokens[$nextPtr]['code'] === T_VARIABLE) {
+            // Is this a namespace name?
+            if ($tokens[$nextPtr]['code'] === T_NS_SEPARATOR) {
                 return;
-            } else if ($phpcsFile->isReference($nextPtr) === true) {
+            }
+
+            // Is this a type hint?
+            if ($tokens[$nextPtr]['code'] === T_VARIABLE
+                || $phpcsFile->isReference($nextPtr) === true
+            ) {
                 return;
             }
 
             // Is this a member var name?
-            $prevPtr = $phpcsFile->findPrevious(array(T_WHITESPACE), ($stackPtr - 1), null, true);
+            $prevPtr = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
             if ($tokens[$prevPtr]['code'] === T_OBJECT_OPERATOR) {
                 return;
             }
 
-            // Is this an instance of declare()
-            $prevPtr = $phpcsFile->findPrevious(array(T_WHITESPACE, T_OPEN_PARENTHESIS), ($stackPtr - 1), null, true);
-            if ($tokens[$prevPtr]['code'] === T_DECLARE) {
+            // Is this a namespace name?
+            if ($tokens[$prevPtr]['code'] === T_NS_SEPARATOR) {
                 return;
             }
 
+            // Is this an instance of declare()
+            $prevPtrDeclare = $phpcsFile->findPrevious(array(T_WHITESPACE, T_OPEN_PARENTHESIS), ($stackPtr - 1), null, true);
+            if ($tokens[$prevPtrDeclare]['code'] === T_DECLARE) {
+                return;
+            }
+
+            // Is this a goto label target?
+            if ($tokens[$nextPtr]['code'] === T_COLON) {
+                if (in_array($tokens[$prevPtr]['code'], array(T_SEMICOLON, T_OPEN_CURLY_BRACKET, T_COLON), true)) {
+                    return;
+                }
+            }
+
             // This is a real constant.
             if (strtoupper($constName) !== $constName) {
-                $error = 'Constants must be uppercase; expected '.strtoupper($constName)." but found $constName";
-                $phpcsFile->addError($error, $stackPtr);
+                $error = 'Constants must be uppercase; expected %s but found %s';
+                $data  = array(
+                          strtoupper($constName),
+                          $constName,
+                         );
+                $phpcsFile->addError($error, $stackPtr, 'ConstantNotUpperCase', $data);
             }
 
         } else if (strtolower($constName) === 'define' || strtolower($constName) === 'constant') {
@@ -130,16 +165,37 @@ class Generic_Sniffs_NamingConventions_UpperCaseConstantNameSniff implements PHP
                 This may be a "define" or "constant" function call.
             */
 
+            // Make sure this is not a method call.
+            $prev = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
+            if ($tokens[$prev]['code'] === T_OBJECT_OPERATOR
+                || $tokens[$prev]['code'] === T_DOUBLE_COLON
+            ) {
+                return;
+            }
+
             // The next non-whitespace token must be the constant name.
-            $constPtr = $phpcsFile->findNext(array(T_WHITESPACE), ($openBracket + 1), null, true);
+            $constPtr = $phpcsFile->findNext(T_WHITESPACE, ($openBracket + 1), null, true);
             if ($tokens[$constPtr]['code'] !== T_CONSTANT_ENCAPSED_STRING) {
                 return;
             }
 
             $constName = $tokens[$constPtr]['content'];
+
+            // Check for constants like self::CONSTANT.
+            $prefix   = '';
+            $splitPos = strpos($constName, '::');
+            if ($splitPos !== false) {
+                $prefix    = substr($constName, 0, ($splitPos + 2));
+                $constName = substr($constName, ($splitPos + 2));
+            }
+
             if (strtoupper($constName) !== $constName) {
-                $error = 'Constants must be uppercase; expected '.strtoupper($constName)." but found $constName";
-                $phpcsFile->addError($error, $stackPtr);
+                $error = 'Constants must be uppercase; expected %s but found %s';
+                $data  = array(
+                          $prefix.strtoupper($constName),
+                          $prefix.$constName,
+                         );
+                $phpcsFile->addError($error, $stackPtr, 'ConstantNotUpperCase', $data);
             }
         }//end if
 
