@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ScopeIndentSniff.php,v 1.11 2008/03/03 03:28:14 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,9 +24,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Sniff
@@ -38,17 +37,17 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
      *
      * @var int
      */
-    protected $indent = 4;
+    public $indent = 4;
 
     /**
      * Does the indent need to be exactly right.
      *
-     * If TRUE, indent needs to be exactly $ident spaces. If FALSE,
-     * indent needs to be at least $ident spaces (but can be more).
+     * If TRUE, indent needs to be exactly $indent spaces. If FALSE,
+     * indent needs to be at least $indent spaces (but can be more).
      *
      * @var bool
      */
-    protected $exact = false;
+    public $exact = false;
 
     /**
      * Any scope openers that should not cause an indent.
@@ -90,7 +89,13 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
         }
 
         if ($tokens[$stackPtr]['code'] === T_ELSE) {
-            $next = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr + 1), null, true);
+            $next = $phpcsFile->findNext(
+                PHP_CodeSniffer_Tokens::$emptyTokens,
+                ($stackPtr + 1),
+                null,
+                true
+            );
+
             // We will handle the T_IF token in another call to process.
             if ($tokens[$next]['code'] === T_IF) {
                 return;
@@ -115,11 +120,19 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
         // indent that we expect this current content to be.
         $expectedIndent = $this->calculateExpectedIndent($tokens, $firstToken);
 
-        if ($tokens[$firstToken]['column'] !== $expectedIndent) {
-            $error  = 'Line indented incorrectly; expected ';
-            $error .= ($expectedIndent - 1).' spaces, found ';
-            $error .= ($tokens[$firstToken]['column'] - 1);
-            $phpcsFile->addError($error, $stackPtr);
+        // Don't process the first token if it is a closure because they have
+        // different indentation rules as they are often used as function arguments
+        // for multi-line function calls. But continue to process the content of the
+        // closure because it should be indented as normal.
+        if ($tokens[$firstToken]['code'] !== T_CLOSURE
+            && $tokens[$firstToken]['column'] !== $expectedIndent
+        ) {
+            $error = 'Line indented incorrectly; expected %s spaces, found %s';
+            $data  = array(
+                      ($expectedIndent - 1),
+                      ($tokens[$firstToken]['column'] - 1),
+                     );
+            $phpcsFile->addError($error, $stackPtr, 'Incorrect', $data);
         }
 
         $scopeOpener = $tokens[$stackPtr]['scope_opener'];
@@ -136,7 +149,7 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
         $commentOpen = false;
         $inHereDoc   = false;
 
-        // Only loop over the content beween the opening and closing brace, not
+        // Only loop over the content between the opening and closing brace, not
         // the braces themselves.
         for ($i = ($scopeOpener + 1); $i < $scopeCloser; $i++) {
 
@@ -145,10 +158,20 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
             if (in_array($tokens[$i]['code'], PHP_CodeSniffer_Tokens::$scopeOpeners) === true) {
                 if (isset($tokens[$i]['scope_opener']) === true) {
                     $i = $tokens[$i]['scope_closer'];
+
+                    // If the scope closer is followed by a semi-colon, the semi-colon is part
+                    // of the closer and should also be ignored. This most commonly happens with
+                    // CASE statements that end with "break;", where we don't want to stop
+                    // ignoring at the break, but rather at the semi-colon.
+                    $nextToken = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($i + 1), null, true);
+                    if ($tokens[$nextToken]['code'] === T_SEMICOLON) {
+                        $i = $nextToken;
+                    }
                 } else {
                     // If this token does not have a scope_opener indice, then
                     // it's probably an inline scope, so let's skip to the next
-                    // semicolon. Inline scopes include inline if's, abstract methods etc.
+                    // semicolon. Inline scopes include inline if's, abstract
+                    // methods etc.
                     $nextToken = $phpcsFile->findNext(T_SEMICOLON, $i, $scopeCloser);
                     if ($nextToken !== false) {
                         $i = $nextToken;
@@ -156,15 +179,20 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                 }
 
                 continue;
-            }
+            }//end if
 
-            // If this is a HEREDOC then we need to ignore it as the whitespace
-            // before the contents within the HEREDOC are considered part of the content.
-            if ($tokens[$i]['code'] === T_START_HEREDOC) {
+            // If this is a HEREDOC then we need to ignore it as the
+            // whitespace before the contents within the HEREDOC are
+            // considered part of the content.
+            if ($tokens[$i]['code'] === T_START_HEREDOC
+                || $tokens[$i]['code'] === T_START_NOWDOC
+            ) {
                 $inHereDoc = true;
                 continue;
             } else if ($inHereDoc === true) {
-                if ($tokens[$i]['code'] === T_END_HEREDOC) {
+                if ($tokens[$i]['code'] === T_END_HEREDOC
+                    || $tokens[$i]['code'] === T_END_NOWDOC
+                ) {
                     $inHereDoc = false;
                 }
 
@@ -187,7 +215,8 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
 
                 // Special case for non-PHP code.
                 if ($tokens[$firstToken]['code'] === T_INLINE_HTML) {
-                    $trimmedContentLength = strlen(ltrim($tokens[$firstToken]['content']));
+                    $trimmedContentLength
+                        = strlen(ltrim($tokens[$firstToken]['content']));
                     if ($trimmedContentLength === 0) {
                         continue;
                     }
@@ -210,16 +239,16 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
 
                 // This is a special condition for T_DOC_COMMENT and C-style
                 // comments, which contain whitespace between each line.
-                if (in_array($tokens[$firstToken]['code'], array(T_COMMENT, T_DOC_COMMENT)) === true) {
-
+                if (in_array($tokens[$firstToken]['code'], PHP_CodeSniffer_Tokens::$commentTokens) === true) {
                     $content = trim($tokens[$firstToken]['content']);
                     if (preg_match('|^/\*|', $content) !== 0) {
                         // Check to see if the end of the comment is on the same line
                         // as the start of the comment. If it is, then we don't
                         // have to worry about opening a comment.
                         if (preg_match('|\*/$|', $content) === 0) {
-                            // We don't have to calculate the column for the start
-                            // of the comment as there is a whitespace token before it.
+                            // We don't have to calculate the column for the
+                            // start of the comment as there is a whitespace
+                            // token before it.
                             $commentOpen = true;
                         }
                     } else if ($commentOpen === true) {
@@ -229,12 +258,22 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                             continue;
                         }
 
-                        $contentLength        = strlen($tokens[$firstToken]['content']);
-                        $trimmedContentLength = strlen(ltrim($tokens[$firstToken]['content']));
-                        $column               = ($contentLength - $trimmedContentLength + 1);
+                        $contentLength = strlen($tokens[$firstToken]['content']);
+                        $trimmedContentLength
+                            = strlen(ltrim($tokens[$firstToken]['content']));
+
+                        $column = ($contentLength - $trimmedContentLength + 1);
                         if (preg_match('|\*/$|', $content) !== 0) {
                             $commentOpen = false;
                         }
+
+                        // We are in a comment, so the indent does not have to
+                        // be exact. The important thing is that the comment opens
+                        // at the correct column and nothing sits closer to the left
+                        // than that opening column.
+                        if ($column > $indent) {
+                            continue;
+                        }
                     }//end if
                 }//end if
 
@@ -243,16 +282,21 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
                 // an error should be shown.
                 if ($column !== $indent) {
                     if ($this->exact === true || $column < $indent) {
-                        $error  = 'Line indented incorrectly; expected ';
+                        $type  = 'IncorrectExact';
+                        $error = 'Line indented incorrectly; expected ';
                         if ($this->exact === false) {
                             $error .= 'at least ';
+                            $type   = 'Incorrect';
                         }
 
-                        $error .= ($indent - 1).' spaces, found ';
-                        $error .= ($column - 1);
-                        $phpcsFile->addError($error, $firstToken);
+                        $error .= '%s spaces, found %s';
+                        $data = array(
+                                  ($indent - 1),
+                                  ($column - 1),
+                                );
+                        $phpcsFile->addError($error, $firstToken, $type, $data);
                     }
-                }
+                }//end if
             }//end if
         }//end for
 
@@ -262,6 +306,9 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
     /**
      * Calculates the expected indent of a token.
      *
+     * Returns the column at which the token should be indented to, so 1 means
+     * that the token should not be indented at all.
+     *
      * @param array $tokens   The stack of tokens for this file.
      * @param int   $stackPtr The position of the token to get indent for.
      *
@@ -271,21 +318,50 @@ class Generic_Sniffs_WhiteSpace_ScopeIndentSniff implements PHP_CodeSniffer_Snif
     {
         $conditionStack = array();
 
+        $inParenthesis = false;
+        if (isset($tokens[$stackPtr]['nested_parenthesis']) === true
+            && empty($tokens[$stackPtr]['nested_parenthesis']) === false
+        ) {
+            $inParenthesis = true;
+        }
+
         // Empty conditions array (top level structure).
         if (empty($tokens[$stackPtr]['conditions']) === true) {
-            return 1;
+            if ($inParenthesis === true) {
+                // Wrapped in parenthesis means it is probably in a
+                // function call (like a closure) so we have to assume indent
+                // is correct here and someone else will check it more
+                // carefully in another sniff.
+                return $tokens[$stackPtr]['column'];
+            } else {
+                return 1;
+            }
         }
 
+        $indent = 0;
+
         $tokenConditions = $tokens[$stackPtr]['conditions'];
         foreach ($tokenConditions as $id => $condition) {
             // If it's an indenting scope ie. it's not in our array of
-            // scopes that don't indent, add it to our condition stack.
+            // scopes that don't indent, increase indent.
             if (in_array($condition, $this->nonIndentingScopes) === false) {
-                $conditionStack[$id] = $condition;
+                if ($condition === T_CLOSURE && $inParenthesis === true) {
+                    // Closures cause problems with indents when they are
+                    // used as function arguments because the code inside them
+                    // is not technically inside the function yet, so the indent
+                    // is always off by one. So instead, use the
+                    // indent of the closure as the base value.
+                    $indent = ($tokens[$id]['column'] - 1);
+                }
+
+                $indent += $this->indent;
             }
         }
 
-        return ((count($conditionStack) * $this->indent) + 1);
+        // Increase by 1 to indiciate that the code should start at a specific column.
+        // E.g., code indented 4 spaces should start at column 5.
+        $indent++;
+        return $indent;
 
     }//end calculateExpectedIndent()
 
