@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: DisallowShortOpenTagUnitTest.php,v 1.2 2006/12/12 02:31:20 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Generic_Tests_PHP_DisallowShortOpenTagUnitTest extends AbstractSniffUnitTest
@@ -44,15 +43,20 @@ class Generic_Tests_PHP_DisallowShortOpenTagUnitTest extends AbstractSniffUnitTe
     public function getErrorList()
     {
         $option = (boolean) ini_get('short_open_tag');
-
-        if ($option === false) {
-            return array();
+        if ($option === true) {
+            return array(
+                    4 => 1,
+                    5 => 1,
+                   );
+        } else if (version_compare(PHP_VERSION, '5.4.0RC1') >= 0) {
+            // Shorthand echo is always available from PHP 5.4.0 but needed the
+            // short_open_tag ini var to be set for versions before this.
+            return array(
+                    4 => 1,
+                   );
         }
 
-        return array(
-                4 => 1,
-                5 => 1,
-               );
+        return array();
 
     }//end getErrorList()
 
