@@ -7,9 +7,8 @@
  * @category  PHP
  * @package   PHP_CodeSniffer_MySource
  * @author    Greg Sherwood <gsherwood@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: UnusedSystemSniff.php,v 1.6 2008/02/05 00:35:03 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -19,14 +18,15 @@
  * @category  PHP
  * @package   PHP_CodeSniffer_MySource
  * @author    Greg Sherwood <gsherwood@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class MySource_Sniffs_Channels_UnusedSystemSniff implements PHP_CodeSniffer_Sniff
 {
 
+
     /**
      * Returns an array of tokens this test wants to listen for.
      *
@@ -80,10 +80,32 @@ class MySource_Sniffs_Channels_UnusedSystemSniff implements PHP_CodeSniffer_Snif
         for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
             if ($tokens[$i]['level'] < $level) {
                 // We have gone out of scope.
+                // If the original include was inside an IF statement that
+                // is checking if the system exists, check the outer scope
+                // as well.
+                if ($tokens[$stackPtr]['level'] === $level) {
+                    // We are still in the base level, so this is the first
+                    // time we have got here.
+                    $conditions = array_keys($tokens[$stackPtr]['conditions']);
+                    if (empty($conditions) === false) {
+                        $cond = array_pop($conditions);
+                        if ($tokens[$cond]['code'] === T_IF) {
+                            $i = $tokens[$cond]['scope_closer'];
+                            $level--;
+                            continue;
+                        }
+                    }
+                }
+
                 break;
-            }
+            }//end if
+
+            $validTokens = array(
+                            T_DOUBLE_COLON,
+                            T_EXTENDS,
+                            T_IMPLEMENTS,
+                           );
 
-            $validTokens = array(T_DOUBLE_COLON, T_EXTENDS, T_IMPLEMENTS);
             if (in_array($tokens[$i]['code'], $validTokens) === false) {
                 continue;
             }
@@ -123,8 +145,9 @@ class MySource_Sniffs_Channels_UnusedSystemSniff implements PHP_CodeSniffer_Snif
         }//end for
 
         // If we get to here, the system was not use.
-        $error = "Included system \"$systemName\" is never used";
-        $phpcsFile->addError($error, $stackPtr);
+        $error = 'Included system "%s" is never used';
+        $data  = array($systemName);
+        $phpcsFile->addError($error, $stackPtr, 'Found', $data);
 
     }//end process()
 
