@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ClassDeclarationSniff.php,v 1.5 2008/05/19 05:59:25 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,14 +22,21 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_Classes_ClassDeclarationSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * The number of spaces code should be indented.
+     *
+     * @var int
+     */
+    public $indent = 4;
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -51,20 +57,19 @@ class PEAR_Sniffs_Classes_ClassDeclarationSniff implements PHP_CodeSniffer_Sniff
      * Processes this test, when one of its tokens is encountered.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
-     * @param int                  $stackPtr  The position of the current token in the
+     * @param integer              $stackPtr  The position of the current token in the
      *                                        stack passed in $tokens.
      *
      * @return void
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        $tokens = $phpcsFile->getTokens();
+        $tokens    = $phpcsFile->getTokens();
+        $errorData = array($tokens[$stackPtr]['content']);
 
         if (isset($tokens[$stackPtr]['scope_opener']) === false) {
-            $error  = 'Possible parse error: ';
-            $error .= $tokens[$stackPtr]['content'];
-            $error .= ' missing opening or closing brace';
-            $phpcsFile->addWarning($error, $stackPtr);
+            $error = 'Possible parse error: %s missing opening or closing brace';
+            $phpcsFile->addWarning($error, $stackPtr, 'MissingBrace', $errorData);
             return;
         }
 
@@ -73,38 +78,42 @@ class PEAR_Sniffs_Classes_ClassDeclarationSniff implements PHP_CodeSniffer_Sniff
         $classLine   = $tokens[$lastContent]['line'];
         $braceLine   = $tokens[$curlyBrace]['line'];
         if ($braceLine === $classLine) {
-            $error  = 'Opening brace of a ';
-            $error .= $tokens[$stackPtr]['content'];
-            $error .= ' must be on the line after the definition';
-            $phpcsFile->addError($error, $curlyBrace);
+            $error = 'Opening brace of a %s must be on the line after the definition';
+            $phpcsFile->addError($error, $curlyBrace, 'OpenBraceNewLine', $errorData);
             return;
         } else if ($braceLine > ($classLine + 1)) {
-            $difference  = ($braceLine - $classLine - 1);
-            $difference .= ($difference === 1) ? ' line' : ' lines';
-            $error       = 'Opening brace of a ';
-            $error      .= $tokens[$stackPtr]['content'];
-            $error      .= ' must be on the line following the ';
-            $error      .= $tokens[$stackPtr]['content'];
-            $error      .= ' declaration; found '.$difference;
-            $phpcsFile->addError($error, $curlyBrace);
+            $error = 'Opening brace of a %s must be on the line following the %s declaration; found %s line(s)';
+            $data  = array(
+                      $tokens[$stackPtr]['content'],
+                      $tokens[$stackPtr]['content'],
+                      ($braceLine - $classLine - 1),
+                     );
+            $phpcsFile->addError($error, $curlyBrace, 'OpenBraceWrongLine', $data);
             return;
         }
 
         if ($tokens[($curlyBrace + 1)]['content'] !== $phpcsFile->eolChar) {
-            $type  = strtolower($tokens[$stackPtr]['content']);
-            $error = "Opening $type brace must be on a line by itself";
-            $phpcsFile->addError($error, $curlyBrace);
+            $error = 'Opening %s brace must be on a line by itself';
+            $phpcsFile->addError($error, $curlyBrace, 'OpenBraceNotAlone', $errorData);
         }
 
         if ($tokens[($curlyBrace - 1)]['code'] === T_WHITESPACE) {
             $prevContent = $tokens[($curlyBrace - 1)]['content'];
-            if ($prevContent !== $phpcsFile->eolChar) {
+            if ($prevContent === $phpcsFile->eolChar) {
+                $spaces = 0;
+            } else {
                 $blankSpace = substr($prevContent, strpos($prevContent, $phpcsFile->eolChar));
                 $spaces     = strlen($blankSpace);
-                if ($spaces !== 0) {
-                    $error = "Expected 0 spaces before opening brace; $spaces found";
-                    $phpcsFile->addError($error, $curlyBrace);
-                }
+            }
+
+            $expected = ($tokens[$stackPtr]['level'] * $this->indent);
+            if ($spaces !== $expected) {
+                $error = 'Expected %s spaces before opening brace; %s found';
+                $data  = array(
+                          $expected,
+                          $spaces,
+                         );
+                $phpcsFile->addError($error, $curlyBrace, 'SpaceBeforeBrace', $data);
             }
         }
 
