@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ValidFunctionNameSniff.php,v 1.18 2008/01/22 23:50:23 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -28,9 +27,9 @@ if (class_exists('PHP_CodeSniffer_Standards_AbstractScopeSniff', true) === false
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniffer_Standards_AbstractScopeSniff
@@ -41,30 +40,29 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
      *
      * @var array
      */
-    private $_magicMethods = array(
-                              'construct',
-                              'destruct',
-                              'call',
-                              'callStatic',
-                              'get',
-                              'set',
-                              'isset',
-                              'unset',
-                              'sleep',
-                              'wakeup',
-                              'toString',
-                              'set_state',
-                              'clone',
-                             );
+    protected $magicMethods = array(
+                               'construct',
+                               'destruct',
+                               'call',
+                               'callStatic',
+                               'get',
+                               'set',
+                               'isset',
+                               'unset',
+                               'sleep',
+                               'wakeup',
+                               'toString',
+                               'set_state',
+                               'clone',
+                               'invoke',
+                              );
 
     /**
      * A list of all PHP magic functions.
      *
      * @var array
      */
-    private $_magicFunctions = array(
-                                'autoload',
-                               );
+    protected $magicFunctions = array('autoload');
 
 
     /**
@@ -89,15 +87,22 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
      */
     protected function processTokenWithinScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr, $currScope)
     {
-        $className  = $phpcsFile->getDeclarationName($currScope);
         $methodName = $phpcsFile->getDeclarationName($stackPtr);
+        if ($methodName === null) {
+            // Ignore closures.
+            return;
+        }
+
+        $className = $phpcsFile->getDeclarationName($currScope);
+        $errorData = array($className.'::'.$methodName);
 
         // Is this a magic method. IE. is prefixed with "__".
         if (preg_match('|^__|', $methodName) !== 0) {
             $magicPart = substr($methodName, 2);
-            if (in_array($magicPart, $this->_magicMethods) === false) {
-                 $error = "Method name \"$className::$methodName\" is invalid; only PHP magic methods should be prefixed with a double underscore";
-                 $phpcsFile->addError($error, $stackPtr);
+            if (in_array($magicPart, $this->magicMethods) === false) {
+                 $error = 'Method name "%s" is invalid; only PHP magic methods should be prefixed with a double underscore';
+                 
+                 $phpcsFile->addError($error, $stackPtr, 'MethodDoubleUnderscore', $errorData);
             }
 
             return;
@@ -120,15 +125,19 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
 
         // If it's a private method, it must have an underscore on the front.
         if ($isPublic === false && $methodName{0} !== '_') {
-            $error = "Private method name \"$className::$methodName\" must be prefixed with an underscore";
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'Private method name "%s" must be prefixed with an underscore';
+            $phpcsFile->addError($error, $stackPtr, 'PrivateNoUnderscore', $errorData);
             return;
         }
 
         // If it's not a private method, it must not have an underscore on the front.
         if ($isPublic === true && $scopeSpecified === true && $methodName{0} === '_') {
-            $error = ucfirst($scope)." method name \"$className::$methodName\" must not be prefixed with an underscore";
-            $phpcsFile->addError($error, $stackPtr);
+            $error = '%s method name "%s" must not be prefixed with an underscore';
+            $data  = array(
+                      ucfirst($scope),
+                      $errorData[0],
+                     );
+            $phpcsFile->addError($error, $stackPtr, 'PublicUnderscore', $data);
             return;
         }
 
@@ -144,12 +153,17 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
 
         if (PHP_CodeSniffer::isCamelCaps($testMethodName, false, $isPublic, false) === false) {
             if ($scopeSpecified === true) {
-                $error = ucfirst($scope)." method name \"$className::$methodName\" is not in camel caps format";
+                $error = '%s method name "%s" is not in camel caps format';
+                $data  = array(
+                          ucfirst($scope),
+                          $errorData[0],
+                         );
+                $phpcsFile->addError($error, $stackPtr, 'ScopeNotCamelCaps', $data);
             } else {
-                $error = "Method name \"$className::$methodName\" is not in camel caps format";
+                $error = 'Method name "%s" is not in camel caps format';
+                $phpcsFile->addError($error, $stackPtr, 'NotCamelCaps', $errorData);
             }
 
-            $phpcsFile->addError($error, $stackPtr);
             return;
         }
 
@@ -168,13 +182,19 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
     protected function processTokenOutsideScope(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
         $functionName = $phpcsFile->getDeclarationName($stackPtr);
+        if ($functionName === null) {
+            // Ignore closures.
+            return;
+        }
+
+        $errorData = array($functionName);
 
         // Is this a magic function. IE. is prefixed with "__".
         if (preg_match('|^__|', $functionName) !== 0) {
             $magicPart = substr($functionName, 2);
-            if (in_array($magicPart, $this->_magicFunctions) === false) {
-                 $error = "Function name \"$functionName\" is invalid; only PHP magic methods should be prefixed with a double underscore";
-                 $phpcsFile->addError($error, $stackPtr);
+            if (in_array($magicPart, $this->magicFunctions) === false) {
+                 $error = 'Function name "%s" is invalid; only PHP magic methods should be prefixed with a double underscore';
+                 $phpcsFile->addError($error, $stackPtr, 'FunctionDoubleUnderscore', $errorData);
             }
 
             return;
@@ -198,22 +218,22 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
         // If it has a package part, make sure the first letter is a capital.
         if ($packagePart !== '') {
             if ($functionName{0} === '_') {
-                $error = "Function name \"$functionName\" is invalid; only private methods should be prefixed with an underscore";
-                $phpcsFile->addError($error, $stackPtr);
+                $error = 'Function name "%s" is invalid; only private methods should be prefixed with an underscore';
+                $phpcsFile->addError($error, $stackPtr, 'FunctionUnderscore', $errorData);
                 return;
             }
 
             if ($functionName{0} !== strtoupper($functionName{0})) {
-                $error = "Function name \"$functionName\" is prefixed with a package name but does not begin with a capital letter";
-                $phpcsFile->addError($error, $stackPtr);
+                $error = 'Function name "%s" is prefixed with a package name but does not begin with a capital letter';
+                $phpcsFile->addError($error, $stackPtr, 'FunctionNoCaptial', $errorData);
                 return;
             }
         }
 
         // If it doesn't have a camel caps part, it's not valid.
         if (trim($camelCapsPart) === '') {
-            $error = "Function name \"$functionName\" is not valid; name appears incomplete";
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'Function name "%s" is not valid; name appears incomplete';
+            $phpcsFile->addError($error, $stackPtr, 'FunctionInvalid', $errorData);
             return;
         }
 
@@ -251,8 +271,10 @@ class PEAR_Sniffs_NamingConventions_ValidFunctionNameSniff extends PHP_CodeSniff
                 $newName = rtrim($newPackagePart, '_').'_'.$newCamelCapsPart;
             }
 
-            $error = "Function name \"$functionName\" is invalid; consider \"$newName\" instead";
-            $phpcsFile->addError($error, $stackPtr);
+            $error  = 'Function name "%s" is invalid; consider "%s" instead';
+            $data   = $errorData;
+            $data[] = $newName;
+            $phpcsFile->addError($error, $stackPtr, 'FunctionNameInvalid', $data);
         }
 
     }//end processTokenOutsideScope()
