@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ArrayDeclarationSniff.php,v 1.19 2008/06/30 05:26:24 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -21,9 +20,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
@@ -57,8 +56,9 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
 
         // Array keyword should be lower case.
         if (strtolower($tokens[$stackPtr]['content']) !== $tokens[$stackPtr]['content']) {
-            $error = 'Array keyword should be lower case; expected "array" but found "'.$tokens[$stackPtr]['content'].'"';
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'Array keyword should be lower case; expected "array" but found "%s"';
+            $data  = array($tokens[$stackPtr]['content']);
+            $phpcsFile->addError($error, $stackPtr, 'NotLowerCase', $data);
         }
 
         $arrayStart   = $tokens[$stackPtr]['parenthesis_opener'];
@@ -67,7 +67,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
 
         if ($arrayStart != ($stackPtr + 1)) {
             $error = 'There must be no space between the Array keyword and the opening parenthesis';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'SpaceAfterKeyword');
         }
 
         // Check for empty arrays.
@@ -76,7 +76,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             // Empty array, but if the brackets aren't together, there's a problem.
             if (($arrayEnd - $arrayStart) !== 1) {
                 $error = 'Empty array declaration must have no space between the parentheses';
-                $phpcsFile->addError($error, $stackPtr);
+                $phpcsFile->addError($error, $stackPtr, 'SpaceInEmptyArray');
 
                 // We can return here because there is nothing else to check. All code
                 // below can assume that the array is not empty.
@@ -88,12 +88,19 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             // Single line array.
             // Check if there are multiple values. If so, then it has to be multiple lines
             // unless it is contained inside a function call or condition.
-            $nextComma  = $arrayStart;
             $valueCount = 0;
             $commas     = array();
-            while (($nextComma = $phpcsFile->findNext(array(T_COMMA), ($nextComma + 1), $arrayEnd)) !== false) {
-                $valueCount++;
-                $commas[] = $nextComma;
+            for ($i = ($arrayStart + 1); $i < $arrayEnd; $i++) {
+                // Skip bracketed statements, like function calls.
+                if ($tokens[$i]['code'] === T_OPEN_PARENTHESIS) {
+                    $i = $tokens[$i]['parenthesis_closer'];
+                    continue;
+                }
+
+                if ($tokens[$i]['code'] === T_COMMA) {
+                    $valueCount++;
+                    $commas[] = $i;
+                }
             }
 
             // Now check each of the double arrows (if any).
@@ -101,27 +108,37 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             while (($nextArrow = $phpcsFile->findNext(T_DOUBLE_ARROW, ($nextArrow + 1), $arrayEnd)) !== false) {
                 if ($tokens[($nextArrow - 1)]['code'] !== T_WHITESPACE) {
                     $content = $tokens[($nextArrow - 1)]['content'];
-                    $error   = "Expected 1 space between \"$content\" and double arrow; 0 found";
-                    $phpcsFile->addError($error, $nextArrow);
+                    $error   = 'Expected 1 space between "%s" and double arrow; 0 found';
+                    $data    = array($content);
+                    $phpcsFile->addError($error, $nextArrow, 'NoSpaceBeforeDoubleArrow', $data);
                 } else {
                     $spaceLength = strlen($tokens[($nextArrow - 1)]['content']);
                     if ($spaceLength !== 1) {
                         $content = $tokens[($nextArrow - 2)]['content'];
-                        $error   = "Expected 1 space between \"$content\" and double arrow; $spaceLength found";
-                        $phpcsFile->addError($error, $nextArrow);
+                        $error   = 'Expected 1 space between "%s" and double arrow; %s found';
+                        $data    = array(
+                                    $content,
+                                    $spaceLength,
+                                   );
+                        $phpcsFile->addError($error, $nextArrow, 'SpaceBeforeDoubleArrow', $data);
                     }
                 }
 
                 if ($tokens[($nextArrow + 1)]['code'] !== T_WHITESPACE) {
                     $content = $tokens[($nextArrow + 1)]['content'];
-                    $error   = "Expected 1 space between double arrow and \"$content\"; 0 found";
-                    $phpcsFile->addError($error, $nextArrow);
+                    $error   = 'Expected 1 space between double arrow and "%s"; 0 found';
+                    $data    = array($content);
+                    $phpcsFile->addError($error, $nextArrow, 'NoSpaceAfterDoubleArrow', $data);
                 } else {
                     $spaceLength = strlen($tokens[($nextArrow + 1)]['content']);
                     if ($spaceLength !== 1) {
                         $content = $tokens[($nextArrow + 2)]['content'];
-                        $error   = "Expected 1 space between double arrow and \"$content\"; $spaceLength found";
-                        $phpcsFile->addError($error, $nextArrow);
+                        $error   = 'Expected 1 space between double arrow and "%s"; %s found';
+                        $data    = array(
+                                    $content,
+                                    $spaceLength,
+                                   );
+                        $phpcsFile->addError($error, $nextArrow, 'SpaceAfterDoubleArrow', $data);
                     }
                 }
             }//end while
@@ -131,7 +148,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
 
                 if (($conditionCheck === false) || ($tokens[$conditionCheck]['line'] !== $tokens[$stackPtr]['line'])) {
                     $error = 'Array with multiple values cannot be declared on a single line';
-                    $phpcsFile->addError($error, $stackPtr);
+                    $phpcsFile->addError($error, $stackPtr, 'SingleLineNotAllowed');
                     return;
                 }
 
@@ -140,22 +157,31 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                 foreach ($commas as $comma) {
                     if ($tokens[($comma + 1)]['code'] !== T_WHITESPACE) {
                         $content = $tokens[($comma + 1)]['content'];
-                        $error   = "Expected 1 space between comma and \"$content\"; 0 found";
-                        $phpcsFile->addError($error, $comma);
+                        $error   = 'Expected 1 space between comma and "%s"; 0 found';
+                        $data    = array($content);
+                        $phpcsFile->addError($error, $comma, 'NoSpaceAfterComma', $data);
                     } else {
                         $spaceLength = strlen($tokens[($comma + 1)]['content']);
                         if ($spaceLength !== 1) {
                             $content = $tokens[($comma + 2)]['content'];
-                            $error   = "Expected 1 space between comma and \"$content\"; $spaceLength found";
-                            $phpcsFile->addError($error, $comma);
+                            $error   = 'Expected 1 space between comma and "%s"; %s found';
+                            $data    = array(
+                                        $content,
+                                        $spaceLength,
+                                       );
+                            $phpcsFile->addError($error, $comma, 'SpaceAfterComma', $data);
                         }
                     }
 
                     if ($tokens[($comma - 1)]['code'] === T_WHITESPACE) {
                         $content     = $tokens[($comma - 2)]['content'];
                         $spaceLength = strlen($tokens[($comma - 1)]['content']);
-                        $error       = "Expected 0 spaces between \"$content\" and comma; $spaceLength found";
-                        $phpcsFile->addError($error, $comma);
+                        $error       = 'Expected 0 spaces between "%s" and comma; %s found';
+                        $data        = array(
+                                        $content,
+                                        $spaceLength,
+                                       );
+                        $phpcsFile->addError($error, $comma, 'SpaceBeforeComma', $data);
                     }
                 }//end foreach
             }//end if
@@ -164,17 +190,20 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
         }//end if
 
         // Check the closing bracket is on a new line.
-        $lastContent = $phpcsFile->findPrevious(array(T_WHITESPACE), ($arrayEnd - 1), $arrayStart, true);
+        $lastContent = $phpcsFile->findPrevious(T_WHITESPACE, ($arrayEnd - 1), $arrayStart, true);
         if ($tokens[$lastContent]['line'] !== ($tokens[$arrayEnd]['line'] - 1)) {
             $error = 'Closing parenthesis of array declaration must be on a new line';
-            $phpcsFile->addError($error, $arrayEnd);
+            $phpcsFile->addError($error, $arrayEnd, 'CloseBraceNewLine');
         } else if ($tokens[$arrayEnd]['column'] !== $keywordStart) {
             // Check the closing bracket is lined up under the a in array.
-            $expected  = $keywordStart;
-            $expected .= ($keywordStart === 0) ? ' space' : ' spaces';
-            $found     = $tokens[$arrayEnd]['column'];
-            $found    .= ($found === 0) ? ' space' : ' spaces';
-            $phpcsFile->addError("Closing parenthesis not aligned correctly; expected $expected but found $found", $arrayEnd);
+            $expected = $keywordStart;
+            $found    = $tokens[$arrayEnd]['column'];
+            $error    = 'Closing parenthesis not aligned correctly; expected %s space(s) but found %s';
+            $data     = array(
+                         $expected,
+                         $found,
+                        );
+            $phpcsFile->addError($error, $arrayEnd, 'CloseBraceNotAligned', $data);
         }
 
         $nextToken  = $stackPtr;
@@ -213,7 +242,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
 
                 if ($keyUsed === true && $lastToken === T_COMMA) {
                     $error = 'No key specified for array entry; first entry specifies key';
-                    $phpcsFile->addError($error, $nextToken);
+                    $phpcsFile->addError($error, $nextToken, 'NoKeySpecified');
                     return;
                 }
 
@@ -221,8 +250,12 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                     if ($tokens[($nextToken - 1)]['code'] === T_WHITESPACE) {
                         $content     = $tokens[($nextToken - 2)]['content'];
                         $spaceLength = strlen($tokens[($nextToken - 1)]['content']);
-                        $error       = "Expected 0 spaces between \"$content\" and comma; $spaceLength found";
-                        $phpcsFile->addError($error, $nextToken);
+                        $error       = 'Expected 0 spaces between "%s" and comma; %s found';
+                        $data        = array(
+                                        $content,
+                                        $spaceLength,
+                                       );
+                        $phpcsFile->addError($error, $nextToken, 'SpaceBeforeComma', $data);
                     }
 
                     // Find the value, which will be the first token on the line,
@@ -250,7 +283,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             if ($tokens[$nextToken]['code'] === T_DOUBLE_ARROW) {
                 if ($singleUsed === true) {
                     $error = 'Key specified for array entry; first entry has no key';
-                    $phpcsFile->addError($error, $nextToken);
+                    $phpcsFile->addError($error, $nextToken, 'KeySpecified');
                     return;
                 }
 
@@ -311,7 +344,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             // Array cannot be empty, so this is a multi-line array with
             // a single value. It should be defined on single line.
             $error = 'Multi-line array contains a single value; use single-line array instead';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'MulitLineNotAllowed');
             return;
         }
 
@@ -333,7 +366,7 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             $trailingContent = $phpcsFile->findPrevious(T_WHITESPACE, ($arrayEnd - 1), $lastIndex, true);
             if ($tokens[$trailingContent]['code'] !== T_COMMA) {
                 $error = 'Comma required after last value in array declaration';
-                $phpcsFile->addError($error, $trailingContent);
+                $phpcsFile->addError($error, $trailingContent, 'NoCommaAfterLast');
             }
 
             foreach ($indices as $value) {
@@ -348,8 +381,12 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
                     // A whitespace token before this value means that the value
                     // was indented and not flush with the opening parenthesis.
                     if ($tokens[$value['value']]['column'] !== ($keywordStart + 1)) {
-                        $error = 'Array value not aligned correctly; expected '.($keywordStart + 1).' spaces but found '.$tokens[$value['value']]['column'];
-                        $phpcsFile->addError($error, $value['value']);
+                        $error = 'Array value not aligned correctly; expected %s spaces but found %s';
+                        $data  = array(
+                                  ($keywordStart + 1),
+                                  $tokens[$value['value']]['column'],
+                                 );
+                        $phpcsFile->addError($error, $value['value'], 'ValueNotAligned', $data);
                     }
                 }
             }
@@ -385,61 +422,85 @@ class Squiz_Sniffs_Arrays_ArrayDeclarationSniff implements PHP_CodeSniffer_Sniff
             if (isset($index['index']) === false) {
                 // Array value only.
                 if (($tokens[$index['value']]['line'] === $tokens[$stackPtr]['line']) && ($numValues > 1)) {
-                    $phpcsFile->addError('The first value in a multi-value array must be on a new line', $stackPtr);
+                    $error = 'The first value in a multi-value array must be on a new line';
+                    $phpcsFile->addError($error, $stackPtr, 'FirstValueNoNewline');
                 }
 
                 continue;
             }
 
-            if (isset($index['index_content']) === true) {
-                $indexContent = trim($index['index_content'], "'");
-                if (preg_match('|^[a-zA-Z0-9_]+$|', $indexContent) === 1) {
-                    if (strtolower($indexContent) !== $indexContent) {
-                        $error = 'Array index "'.$indexContent.'" should not contain uppercase characters';
-                        $phpcsFile->addError($error, $index['index']);
-                    }
-                }
-            }
-
             if (($tokens[$index['index']]['line'] === $tokens[$stackPtr]['line'])) {
-                $phpcsFile->addError('The first index in a multi-value array must be on a new line', $stackPtr);
+                $error = 'The first index in a multi-value array must be on a new line';
+                $phpcsFile->addError($error, $stackPtr, 'FirstIndexNoNewline');
                 continue;
             }
 
             if ($tokens[$index['index']]['column'] !== $indicesStart) {
-                $phpcsFile->addError('Array key not aligned correctly; expected '.$indicesStart.' spaces but found '.$tokens[$index['index']]['column'], $index['index']);
+                $error = 'Array key not aligned correctly; expected %s spaces but found %s';
+                $data  = array(
+                          ($indicesStart - 1),
+                          ($tokens[$index['index']]['column'] - 1),
+                         );
+                $phpcsFile->addError($error, $index['index'], 'KeyNotAligned', $data);
                 continue;
             }
 
             if ($tokens[$index['arrow']]['column'] !== $arrowStart) {
-                $expected  = ($arrowStart - (strlen($index['index_content']) + $tokens[$index['index']]['column']));
-                $expected .= ($expected === 1) ? ' space' : ' spaces';
-                $found     = ($tokens[$index['arrow']]['column'] - (strlen($index['index_content']) + $tokens[$index['index']]['column']));
-                $phpcsFile->addError("Array double arrow not aligned correctly; expected $expected but found $found", $index['arrow']);
+                $expected = ($arrowStart - (strlen($index['index_content']) + $tokens[$index['index']]['column']));
+                $found    = ($tokens[$index['arrow']]['column'] - (strlen($index['index_content']) + $tokens[$index['index']]['column']));
+
+                $error = 'Array double arrow not aligned correctly; expected %s space(s) but found %s';
+                $data  = array(
+                          $expected,
+                          $found,
+                         );
+                $phpcsFile->addError($error, $index['arrow'], 'DoubleArrowNotAligned', $data);
                 continue;
             }
 
             if ($tokens[$index['value']]['column'] !== $valueStart) {
-                $expected  = ($valueStart - (strlen($tokens[$index['arrow']]['content']) + $tokens[$index['arrow']]['column']));
-                $expected .= ($expected === 1) ? ' space' : ' spaces';
-                $found     = ($tokens[$index['value']]['column'] - (strlen($tokens[$index['arrow']]['content']) + $tokens[$index['arrow']]['column']));
-                $phpcsFile->addError("Array value not aligned correctly; expected $expected but found $found", $index['arrow']);
+                $expected = ($valueStart - (strlen($tokens[$index['arrow']]['content']) + $tokens[$index['arrow']]['column']));
+                $found    = ($tokens[$index['value']]['column'] - (strlen($tokens[$index['arrow']]['content']) + $tokens[$index['arrow']]['column']));
+
+                $error = 'Array value not aligned correctly; expected %s space(s) but found %s';
+                $data  = array(
+                          $expected,
+                          $found,
+                         );
+                $phpcsFile->addError($error, $index['arrow'], 'ValueNotAligned', $data);
             }
 
             // Check each line ends in a comma.
             if ($tokens[$index['value']]['code'] !== T_ARRAY) {
-                $nextComma = $phpcsFile->findNext(array(T_COMMA), ($index['value'] + 1));
+                $nextComma = false;
+                for ($i = ($index['value'] + 1); $i < $arrayEnd; $i++) {
+                    // Skip bracketed statements, like function calls.
+                    if ($tokens[$i]['code'] === T_OPEN_PARENTHESIS) {
+                        $i = $tokens[$i]['parenthesis_closer'];
+                        continue;
+                    }
+
+                    if ($tokens[$i]['code'] === T_COMMA) {
+                        $nextComma = $i;
+                        break;
+                    }
+                }
+
                 if (($nextComma === false) || ($tokens[$nextComma]['line'] !== $tokens[$index['value']]['line'])) {
                     $error = 'Each line in an array declaration must end in a comma';
-                    $phpcsFile->addError($error, $index['value']);
+                    $phpcsFile->addError($error, $index['value'], 'NoComma');
                 }
 
                 // Check that there is no space before the comma.
                 if ($nextComma !== false && $tokens[($nextComma - 1)]['code'] === T_WHITESPACE) {
                     $content     = $tokens[($nextComma - 2)]['content'];
                     $spaceLength = strlen($tokens[($nextComma - 1)]['content']);
-                    $error       = "Expected 0 spaces between \"$content\" and comma; $spaceLength found";
-                    $phpcsFile->addError($error, $nextComma);
+                    $error       = 'Expected 0 spaces between "%s" and comma; %s found';
+                    $data        = array(
+                                    $content,
+                                    $spaceLength,
+                                   );
+                    $phpcsFile->addError($error, $nextComma, 'SpaceBeforeComma', $data);
                 }
             }
         }//end foreach
