@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: SelfMemberReferenceSniff.php,v 1.5 2007/12/05 03:31:16 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -33,9 +32,9 @@ if (class_exists('PHP_CodeSniffer_Standards_AbstractScopeSniff', true) === false
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Classes_SelfMemberReferenceSniff extends PHP_CodeSniffer_Standards_AbstractScopeSniff
@@ -68,31 +67,37 @@ class Squiz_Sniffs_Classes_SelfMemberReferenceSniff extends PHP_CodeSniffer_Stan
         $className = ($stackPtr - 1);
         if ($tokens[$className]['code'] === T_SELF) {
             if (strtolower($tokens[$className]['content']) !== $tokens[$className]['content']) {
-                $error = 'Must use "self::" for local static member reference; found "'.$tokens[$className]['content'].'::"';
-                $phpcsFile->addError($error, $className);
+                $error = 'Must use "self::" for local static member reference; found "%s::"';
+                $data  = array($tokens[$className]['content']);
+                $phpcsFile->addError($error, $className, 'IncorrectCase', $data);
                 return;
             }
         } else if ($tokens[$className]['code'] === T_STRING) {
             // Make sure this is another class reference.
             $declarationName = $phpcsFile->getDeclarationName($currScope);
             if ($declarationName === $tokens[$className]['content']) {
-                // Class name is the same as the current class.
-                $error = 'Must use "self::" for local static member reference';
-                $phpcsFile->addError($error, $className);
-                return;
+                // Class name is the same as the current class, which is not allowed
+                // except if being used inside a closure.
+                if ($phpcsFile->hasCondition($stackPtr, T_CLOSURE) === false) {
+                    $error = 'Must use "self::" for local static member reference';
+                    $phpcsFile->addError($error, $className, 'NotUsed');
+                    return;
+                }
             }
         }
 
         if ($tokens[($stackPtr - 1)]['code'] === T_WHITESPACE) {
             $found = strlen($tokens[($stackPtr - 1)]['content']);
-            $error = "Expected 0 spaces before double colon; $found found";
-            $phpcsFile->addError($error, $className);
+            $error = 'Expected 0 spaces before double colon; %s found';
+            $data  = array($found);
+            $phpcsFile->addError($error, $className, 'SpaceBefore', $data);
         }
 
         if ($tokens[($stackPtr + 1)]['code'] === T_WHITESPACE) {
             $found = strlen($tokens[($stackPtr + 1)]['content']);
-            $error = "Expected 0 spaces after double colon; $found found";
-            $phpcsFile->addError($error, $className);
+            $error = 'Expected 0 spaces after double colon; %s found';
+            $data  = array($found);
+            $phpcsFile->addError($error, $className, 'SpaceAfter', $data);
         }
 
     }//end processTokenWithinScope()
