@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: InlineCommentSniff.php,v 1.11 2008/02/26 03:47:35 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,14 +22,23 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -64,22 +72,51 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
         // We are only interested in inline doc block comments, which are
         // not allowed.
         if ($tokens[$stackPtr]['code'] === T_DOC_COMMENT) {
-            $nextToken = $phpcsFile->findNext(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr + 1), null, true);
-            $ignore    = array(
-                          T_CLASS,
-                          T_INTERFACE,
-                          T_FUNCTION,
-                          T_PUBLIC,
-                          T_PRIVATE,
-                          T_PROTECTED,
-                          T_STATIC,
-                          T_ABSTRACT,
-                          T_CONST,
-                         );
+            $nextToken = $phpcsFile->findNext(
+                PHP_CodeSniffer_Tokens::$emptyTokens,
+                ($stackPtr + 1),
+                null,
+                true
+            );
+
+            $ignore = array(
+                       T_CLASS,
+                       T_INTERFACE,
+                       T_FUNCTION,
+                       T_PUBLIC,
+                       T_PRIVATE,
+                       T_PROTECTED,
+                       T_FINAL,
+                       T_STATIC,
+                       T_ABSTRACT,
+                       T_CONST,
+                       T_OBJECT,
+                       T_PROPERTY,
+                      );
+
             if (in_array($tokens[$nextToken]['code'], $ignore) === true) {
                 return;
             } else {
-                $prevToken = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$emptyTokens, ($stackPtr - 1), null, true);
+                if ($phpcsFile->tokenizerType === 'JS') {
+                    // We allow block comments if a function is being assigned
+                    // to a variable.
+                    $ignore    = PHP_CodeSniffer_Tokens::$emptyTokens;
+                    $ignore[]  = T_EQUAL;
+                    $ignore[]  = T_STRING;
+                    $ignore[]  = T_OBJECT_OPERATOR;
+                    $nextToken = $phpcsFile->findNext($ignore, ($nextToken + 1), null, true);
+                    if ($tokens[$nextToken]['code'] === T_FUNCTION) {
+                        return;
+                    }
+                }
+
+                $prevToken = $phpcsFile->findPrevious(
+                    PHP_CodeSniffer_Tokens::$emptyTokens,
+                    ($stackPtr - 1),
+                    null,
+                    true
+                );
+
                 if ($tokens[$prevToken]['code'] === T_OPEN_TAG) {
                     return;
                 }
@@ -87,24 +124,37 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
                 // Only error once per comment.
                 if (substr($tokens[$stackPtr]['content'], 0, 3) === '/**') {
                     $error  = 'Inline doc block comments are not allowed; use "/* Comment */" or "// Comment" instead';
-                    $phpcsFile->addError($error, $stackPtr);
+                    $phpcsFile->addError($error, $stackPtr, 'DocBlock');
                 }
-            }
-        }
+            }//end if
+        }//end if
 
         if ($tokens[$stackPtr]['content']{0} === '#') {
             $error  = 'Perl-style comments are not allowed; use "// Comment" instead';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'WrongStyle');
         }
 
         // We don't want end of block comments. If the last comment is a closing
         // curly brace.
-        $previousContent = $phpcsFile->findPrevious(array(T_WHITESPACE), ($stackPtr - 1), null, true);
-        if (($tokens[$previousContent]['line'] === $tokens[$stackPtr]['line']) && ($tokens[$previousContent]['code'] === T_CLOSE_CURLY_BRACKET)) {
-            return;
+        $previousContent = $phpcsFile->findPrevious(T_WHITESPACE, ($stackPtr - 1), null, true);
+        if ($tokens[$previousContent]['line'] === $tokens[$stackPtr]['line']) {
+            if ($tokens[$previousContent]['code'] === T_CLOSE_CURLY_BRACKET) {
+                return;
+            }
+
+            // Special case for JS files.
+            if ($tokens[$previousContent]['code'] === T_COMMA
+                || $tokens[$previousContent]['code'] === T_SEMICOLON
+            ) {
+                $lastContent = $phpcsFile->findPrevious(T_WHITESPACE, ($previousContent - 1), null, true);
+                if ($tokens[$lastContent]['code'] === T_CLOSE_CURLY_BRACKET) {
+                    return;
+                }
+            }
         }
 
         $comment = rtrim($tokens[$stackPtr]['content']);
+
         // Only want inline comments.
         if (substr($comment, 0, 2) !== '//') {
             return;
@@ -120,13 +170,22 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
         }
 
         if ($spaceCount === 0) {
-            $error = 'No space before comment text; expected "// '.substr($comment, 2).'" but found "'.$comment.'"';
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'No space before comment text; expected "// %s" but found "%s"';
+            $data  = array(
+                      substr($comment, 2),
+                      $comment,
+                     );
+            $phpcsFile->addError($error, $stackPtr, 'NoSpaceBefore', $data);
         }
 
         if ($spaceCount > 1) {
-            $error = $spaceCount.' spaces found before inline comment; expected "// '.substr($comment, (2 + $spaceCount)).'" but found "'.$comment.'"';
-            $phpcsFile->addError($error, $stackPtr);
+            $error = '%s spaces found before inline comment; expected "// %s" but found "%s"';
+            $data  = array(
+                      $spaceCount,
+                      substr($comment, (2 + $spaceCount)),
+                      $comment,
+                     );
+            $phpcsFile->addError($error, $stackPtr, 'SpacingBefore', $data);
         }
 
 
@@ -160,13 +219,13 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
 
         if ($commentText === '') {
             $error = 'Blank comments are not allowed';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'Empty');
             return;
         }
 
         if (preg_match('|[A-Z]|', $commentText[0]) === 0) {
             $error = 'Inline comments must start with a capital letter';
-            $phpcsFile->addError($error, $topComment);
+            $phpcsFile->addError($error, $topComment, 'NotCapital');
         }
 
         $commentCloser   = $commentText[(strlen($commentText) - 1)];
@@ -177,13 +236,15 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
                            );
 
         if (in_array($commentCloser, $acceptedClosers) === false) {
-            $error = 'Inline comments must end in';
+            $error = 'Inline comments must end in %s';
+            $ender = '';
             foreach ($acceptedClosers as $closerName => $symbol) {
-                $error .= ' '.$closerName.',';
+                $ender .= ' '.$closerName.',';
             }
 
-            $error = rtrim($error, ',');
-            $phpcsFile->addError($error, $stackPtr);
+            $ender = rtrim($ender, ',');
+            $data  = array($ender);
+            $phpcsFile->addError($error, $stackPtr, 'InvalidEndChar', $data);
         }
 
         // Finally, the line below the last comment cannot be empty.
@@ -199,7 +260,7 @@ class Squiz_Sniffs_Commenting_InlineCommentSniff implements PHP_CodeSniffer_Snif
         }
 
         $error = 'There must be no blank line following an inline comment';
-        $phpcsFile->addError($error, $stackPtr);
+        $phpcsFile->addError($error, $stackPtr, 'SpacingAfter');
 
     }//end process()
 
