@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: LongConditionClosingCommentSniff.php,v 1.5 2007/07/23 01:47:53 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -21,14 +20,24 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Commenting_LongConditionClosingCommentSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
     /**
      * The openers that we are interested in.
      *
@@ -40,6 +49,8 @@ class Squiz_Sniffs_Commenting_LongConditionClosingCommentSniff implements PHP_Co
                                 T_FOR,
                                 T_FOREACH,
                                 T_WHILE,
+                                T_TRY,
+                                T_CASE,
                                );
 
     /**
@@ -104,9 +115,14 @@ class Squiz_Sniffs_Commenting_LongConditionClosingCommentSniff implements PHP_Co
                 $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
                 if ($tokens[$nextToken]['code'] === T_ELSE || $tokens[$nextToken]['code'] === T_ELSEIF) {
                     // Check for ELSE IF (2 tokens) as opposed to ELSEIF (1 token).
-                    if ($tokens[$nextToken]['code'] === T_ELSE && isset($tokens[$nextToken]['scope_closer']) === false) {
+                    if ($tokens[$nextToken]['code'] === T_ELSE
+                        && isset($tokens[$nextToken]['scope_closer']) === false
+                    ) {
                         $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($nextToken + 1), null, true);
-                        if ($tokens[$nextToken]['code'] !== T_IF) {
+                        if ($tokens[$nextToken]['code'] !== T_IF
+                            || isset($tokens[$nextToken]['scope_closer']) === false
+                        ) {
+                            // Not an ELSE IF or is an inline ELSE IF.
                             break;
                         }
                     }
@@ -120,29 +136,49 @@ class Squiz_Sniffs_Commenting_LongConditionClosingCommentSniff implements PHP_Co
             } while (isset($tokens[$nextToken]['scope_closer']) === true);
         }//end if
 
-        $lineDifference = ($endBrace['line'] - $startBrace['line']);
-        if ($lineDifference < $this->lineLimit) {
-            return;
+        if ($startCondition['code'] === T_TRY) {
+            // TRY statements need to check until the end of all CATCH statements.
+            do {
+                $nextToken = $phpcsFile->findNext(T_WHITESPACE, ($stackPtr + 1), null, true);
+                if ($tokens[$nextToken]['code'] === T_CATCH) {
+                    // The end brace becomes the CATCH's end brace.
+                    $stackPtr = $tokens[$nextToken]['scope_closer'];
+                    $endBrace = $tokens[$stackPtr];
+                } else {
+                    break;
+                }
+            } while (isset($tokens[$nextToken]['scope_closer']) === true);
         }
 
+        $lineDifference = ($endBrace['line'] - $startBrace['line']);
+
         $expected = '//end '.$startCondition['content'];
+        $comment  = $phpcsFile->findNext(array(T_COMMENT), $stackPtr, null, false);
 
-        $comment = $phpcsFile->findNext(array(T_COMMENT), $stackPtr, null, false);
         if (($comment === false) || ($tokens[$comment]['line'] !== $endBrace['line'])) {
-            $error = "End comment for long condition not found; expected \"$expected\"";
-            $phpcsFile->addError($error, $stackPtr);
+            if ($lineDifference >= $this->lineLimit) {
+                $error = 'End comment for long condition not found; expected "%s"';
+                $data  = array($expected);
+                $phpcsFile->addError($error, $stackPtr, 'Missing', $data);
+            }
+
             return;
         }
 
         if (($comment - $stackPtr) !== 1) {
-            $error = "Space found before closing comment; expected \"$expected\"";
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'Space found before closing comment; expected "%s"';
+            $data  = array($expected);
+            $phpcsFile->addError($error, $stackPtr, 'SpacingBefore', $data);
         }
 
-        if ((strpos(trim($tokens[$comment]['content']), $expected)) === false) {
+        if (trim($tokens[$comment]['content']) !== $expected) {
             $found = trim($tokens[$comment]['content']);
-            $error = "Incorrect closing comment; expected \"$expected\" but found \"$found\"";
-            $phpcsFile->addError($error, $stackPtr);
+            $error = 'Incorrect closing comment; expected "%s" but found "%s"';
+            $data  = array(
+                      $expected,
+                      $found,
+                     );
+            $phpcsFile->addError($error, $stackPtr, 'Invalid', $data);
             return;
         }
 
