@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: VariableCommentSniff.php,v 1.21 2008/02/21 23:14:17 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -38,9 +37,9 @@ if (class_exists('PHP_CodeSniffer_CommentParser_MemberCommentParser', true) ===
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -76,55 +75,62 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
         // Extract the var comment docblock.
         $commentEnd = $phpcsFile->findPrevious($commentToken, ($stackPtr - 3));
         if ($commentEnd !== false && $tokens[$commentEnd]['code'] === T_COMMENT) {
-            $phpcsFile->addError('You must use "/**" style comments for a variable comment', $stackPtr);
+            $phpcsFile->addError('You must use "/**" style comments for a variable comment', $stackPtr, 'WrongStyle');
             return;
         } else if ($commentEnd === false || $tokens[$commentEnd]['code'] !== T_DOC_COMMENT) {
-            $phpcsFile->addError('Missing variable doc comment', $stackPtr);
+            $phpcsFile->addError('Missing variable doc comment', $stackPtr, 'Missing');
             return;
         } else {
             // Make sure the comment we have found belongs to us.
             $commentFor = $phpcsFile->findNext(array(T_VARIABLE, T_CLASS, T_INTERFACE), ($commentEnd + 1));
             if ($commentFor !== $stackPtr) {
-                $phpcsFile->addError('Missing variable doc comment', $stackPtr);
+                $phpcsFile->addError('Missing variable doc comment', $stackPtr, 'Missing');
                 return;
             }
         }
 
-        $commentStart = ($phpcsFile->findPrevious(T_DOC_COMMENT, ($commentEnd - 1), null, true) + 1);
-        $comment      = $phpcsFile->getTokensAsString($commentStart, ($commentEnd - $commentStart + 1));
+        $commentStart  = ($phpcsFile->findPrevious(T_DOC_COMMENT, ($commentEnd - 1), null, true) + 1);
+        $commentString = $phpcsFile->getTokensAsString($commentStart, ($commentEnd - $commentStart + 1));
 
         // Parse the header comment docblock.
         try {
-            $this->commentParser = new PHP_CodeSniffer_CommentParser_MemberCommentParser($comment, $phpcsFile);
+            $this->commentParser = new PHP_CodeSniffer_CommentParser_MemberCommentParser($commentString, $phpcsFile);
             $this->commentParser->parse();
         } catch (PHP_CodeSniffer_CommentParser_ParserException $e) {
             $line = ($e->getLineWithinComment() + $commentStart);
-            $phpcsFile->addError($e->getMessage(), $line);
+            $phpcsFile->addError($e->getMessage(), $line, 'ErrorParsing');
             return;
         }
 
         $comment = $this->commentParser->getComment();
         if (is_null($comment) === true) {
             $error = 'Variable doc comment is empty';
-            $phpcsFile->addError($error, $commentStart);
+            $phpcsFile->addError($error, $commentStart, 'Empty');
             return;
         }
 
+        // The first line of the comment should just be the /** code.
+        $eolPos    = strpos($commentString, $phpcsFile->eolChar);
+        $firstLine = substr($commentString, 0, $eolPos);
+        if ($firstLine !== '/**') {
+            $error = 'The open comment tag must be the only content on the line';
+            $phpcsFile->addError($error, $commentStart, 'ContentAfterOpen');
+        }
+
         // Check for a comment description.
         $short = $comment->getShortComment();
         $long  = '';
         if (trim($short) === '') {
             $error = 'Missing short description in variable doc comment';
-            $phpcsFile->addError($error, $commentStart);
+            $phpcsFile->addError($error, $commentStart, 'MissingShort');
             $newlineCount = 1;
         } else {
             // No extra newline before short description.
             $newlineCount = 0;
             $newlineSpan  = strspn($short, $phpcsFile->eolChar);
             if ($short !== '' && $newlineSpan > 0) {
-                $line  = ($newlineSpan > 1) ? 'newlines' : 'newline';
-                $error = "Extra $line found before variable comment short description";
-                $phpcsFile->addError($error, ($commentStart + 1));
+                $error = 'Extra newline(s) found before variable comment short description';
+                $phpcsFile->addError($error, ($commentStart + 1), 'SpacingBeforeShort');
             }
 
             $newlineCount = (substr_count($short, $phpcsFile->eolChar) + 1);
@@ -136,7 +142,7 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
                 $newlineBetween = substr_count($between, $phpcsFile->eolChar);
                 if ($newlineBetween !== 2) {
                     $error = 'There must be exactly one blank line between descriptions in variable comment';
-                    $phpcsFile->addError($error, ($commentStart + $newlineCount + 1));
+                    $phpcsFile->addError($error, ($commentStart + $newlineCount + 1), 'SpacingBetween');
                 }
 
                 $newlineCount += $newlineBetween;
@@ -144,7 +150,7 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
                 $testLong = trim($long);
                 if (preg_match('|[A-Z]|', $testLong[0]) === 0) {
                     $error = 'Variable comment long description must start with a capital letter';
-                    $phpcsFile->addError($error, ($commentStart + $newlineCount));
+                    $phpcsFile->addError($error, ($commentStart + $newlineCount), 'LongNotCapital');
                 }
             }//end if
 
@@ -153,17 +159,17 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
             $lastChar  = $testShort[(strlen($testShort) - 1)];
             if (substr_count($testShort, $phpcsFile->eolChar) !== 0) {
                 $error = 'Variable comment short description must be on a single line';
-                $phpcsFile->addError($error, ($commentStart + 1));
+                $phpcsFile->addError($error, ($commentStart + 1), 'ShortSingleLine');
             }
 
             if (preg_match('|[A-Z]|', $testShort[0]) === 0) {
                 $error = 'Variable comment short description must start with a capital letter';
-                $phpcsFile->addError($error, ($commentStart + 1));
+                $phpcsFile->addError($error, ($commentStart + 1), 'ShortNotCapital');
             }
 
             if ($lastChar !== '.') {
                 $error = 'Variable comment short description must end with a full stop';
-                $phpcsFile->addError($error, ($commentStart + 1));
+                $phpcsFile->addError($error, ($commentStart + 1), 'ShortFullStop');
             }
         }//end if
 
@@ -177,7 +183,7 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
                     $newlineCount += (substr_count($long, $phpcsFile->eolChar) - $newlineSpan + 1);
                 }
 
-                $phpcsFile->addError($error, ($commentStart + $newlineCount));
+                $phpcsFile->addError($error, ($commentStart + $newlineCount), 'SpacingBeforeTags');
                 $short = rtrim($short, $phpcsFile->eolChar.' ');
             }
         }
@@ -186,15 +192,28 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
         $unknownTags = $this->commentParser->getUnknown();
         foreach ($unknownTags as $errorTag) {
             // Unknown tags are not parsed, do not process further.
-            $error = "@$errorTag[tag] tag is not allowed in variable comment";
-            $phpcsFile->addWarning($error, ($commentStart + $errorTag['line']));
+            $error = '@%s tag is not allowed in variable comment';
+            $data  = array($errorTag['tag']);
+            $phpcsFile->addWarning($error, ($commentStart + $errorTag['line']), 'TagNotAllowed', $data);
         }
 
         // Check each tag.
         $this->processVar($commentStart, $commentEnd);
-        $this->processSince($commentStart, $commentEnd);
         $this->processSees($commentStart);
 
+        // The last content should be a newline and the content before
+        // that should not be blank. If there is more blank space
+        // then they have additional blank lines at the end of the comment.
+        $words   = $this->commentParser->getWords();
+        $lastPos = (count($words) - 1);
+        if (trim($words[($lastPos - 1)]) !== ''
+            || strpos($words[($lastPos - 1)], $this->currentFile->eolChar) === false
+            || trim($words[($lastPos - 2)]) === ''
+        ) {
+            $error = 'Additional blank lines found at end of variable comment';
+            $this->currentFile->addError($error, $commentEnd, 'SpacingAfter');
+        }
+
     }//end processMemberVar()
 
 
@@ -216,97 +235,46 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
 
             if (count($index) > 1) {
                 $error = 'Only 1 @var tag is allowed in variable comment';
-                $this->currentFile->addError($error, $errorPos);
+                $this->currentFile->addError($error, $errorPos, 'DuplicateVar');
                 return;
             }
 
             if ($index[0] !== 1) {
                 $error = 'The @var tag must be the first tag in a variable comment';
-                $this->currentFile->addError($error, $errorPos);
+                $this->currentFile->addError($error, $errorPos, 'VarOrder');
             }
 
             $content = $var->getContent();
             if (empty($content) === true) {
                 $error = 'Var type missing for @var tag in variable comment';
-                $this->currentFile->addError($error, $errorPos);
+                $this->currentFile->addError($error, $errorPos, 'MissingVarType');
                 return;
             } else {
                 $suggestedType = PHP_CodeSniffer::suggestType($content);
                 if ($content !== $suggestedType) {
-                    $error = "Expected \"$suggestedType\"; found \"$content\" for @var tag in variable comment";
-                    $this->currentFile->addError($error, $errorPos);
+                    $error = 'Expected "%s"; found "%s" for @var tag in variable comment';
+                    $data  = array(
+                              $suggestedType,
+                              $content,
+                             );
+                    $this->currentFile->addError($error, $errorPos, 'IncorrectVarType', $data);
                 }
             }
 
             $spacing = substr_count($var->getWhitespaceBeforeContent(), ' ');
-            if ($spacing !== 3) {
-                $error  = '@var tag indented incorrectly. ';
-                $error .= "Expected 3 spaces but found $spacing.";
-                $this->currentFile->addError($error, $errorPos);
+            if ($spacing !== 1) {
+                $error = '@var tag indented incorrectly; expected 1 space but found %s';
+                $data  = array($spacing);
+                $this->currentFile->addError($error, $errorPos, 'VarIndent', $data);
             }
         } else {
             $error = 'Missing @var tag in variable comment';
-            $this->currentFile->addError($error, $commentEnd);
+            $this->currentFile->addError($error, $commentEnd, 'MissingVar');
         }//end if
 
     }//end processVar()
 
 
-    /**
-     * Process the since tag.
-     *
-     * @param int $commentStart The position in the stack where the comment started.
-     * @param int $commentEnd   The position in the stack where the comment ended.
-     *
-     * @return void
-     */
-    protected function processSince($commentStart, $commentEnd)
-    {
-        $since = $this->commentParser->getSince();
-        if ($since !== null) {
-            $errorPos  = ($commentStart + $since->getLine());
-            $foundTags = $this->commentParser->getTagOrders();
-            $index     = array_keys($foundTags, 'since');
-            $var       = array_keys($foundTags, 'var');
-
-            if (count($index) > 1) {
-                $error = 'Only 1 @since tag is allowed in variable comment';
-                $this->currentFile->addError($error, $errorPos);
-                return;
-            }
-
-            // Only check order if there is one var tag in variable comment.
-            if (count($var) === 1 && $index[0] !== 2) {
-                $error = 'The order of @since tag is wrong in variable comment';
-                $this->currentFile->addError($error, $errorPos);
-            }
-
-            $content = $since->getContent();
-            if (empty($content) === true) {
-                $error = 'Version number missing for @since tag in variable comment';
-                $this->currentFile->addError($error, $errorPos);
-                return;
-            } else if ($content !== '%release_version%') {
-                if (preg_match('/^([0-9]+)\.([0-9]+)\.([0-9]+)/', $content) === 0) {
-                    $error = 'Expected version number to be in the form x.x.x in @since tag';
-                    $this->currentFile->addError($error, $errorPos);
-                }
-            }
-
-            $spacing = substr_count($since->getWhitespaceBeforeContent(), ' ');
-            if ($spacing !== 1) {
-                $error  = '@since tag indented incorrectly. ';
-                $error .= "Expected 1 space but found $spacing.";
-                $this->currentFile->addError($error, $errorPos);
-            }
-        } else {
-            $error = 'Missing @since tag in variable comment';
-            $this->currentFile->addError($error, $commentEnd);
-        }//end if
-
-    }//end processSince()
-
-
     /**
      * Process the see tags.
      *
@@ -323,15 +291,15 @@ class Squiz_Sniffs_Commenting_VariableCommentSniff extends PHP_CodeSniffer_Stand
                 $content  = $see->getContent();
                 if (empty($content) === true) {
                     $error = 'Content missing for @see tag in variable comment';
-                    $this->currentFile->addError($error, $errorPos);
+                    $this->currentFile->addError($error, $errorPos, 'EmptySees');
                     continue;
                 }
 
                 $spacing = substr_count($see->getWhitespaceBeforeContent(), ' ');
-                if ($spacing !== 3) {
-                    $error  = '@see tag indented incorrectly. ';
-                    $error .= "Expected 3 spaces but found $spacing.";
-                    $this->currentFile->addError($error, $errorPos);
+                if ($spacing !== 1) {
+                    $error = '@see tag indented incorrectly; expected 1 spaces but found %s';
+                    $data  = array($spacing);
+                    $this->currentFile->addError($error, $errorPos, 'SeesIndent', $data);
                 }
             }
         }
