@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: OperatorBracketSniff.php,v 1.10 2008/03/17 03:52:43 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sniff
@@ -67,6 +66,13 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
     {
         $tokens = $phpcsFile->getTokens();
 
+        if ($phpcsFile->tokenizerType === 'JS' && $tokens[$stackPtr]['code'] === T_PLUS) {
+            // JavaScript uses the plus operator for string concatenation as well
+            // so we cannot accurately determine if it is a string concat or addition.
+            // So just ignore it.
+            return;
+        }
+
         // If the & is a reference, then we don't want to check for brackets.
         if ($tokens[$stackPtr]['code'] === T_BITWISE_AND && $phpcsFile->isReference($stackPtr) === true) {
             return;
@@ -94,7 +100,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                         // adjacent.
                         if (($number - $stackPtr) !== 1) {
                             $error = 'No space allowed between minus sign and number';
-                            $phpcsFile->addError($error, $stackPtr);
+                            $phpcsFile->addError($error, $stackPtr, 'SpacingAfterMinus');
                         }
 
                         return;
@@ -116,15 +122,20 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                     break;
                 }
 
-                if ($prevCode === T_STRING) {
-                    // We allow very simple operations to not be bracketed:
-                    // ceil($one / $two);
+                if ($prevCode === T_STRING || $prevCode === T_SWITCH) {
+                    // We allow very simple operations to not be bracketed.
+                    // For example, ceil($one / $two).
                     $allowed = array(
                                 T_VARIABLE,
                                 T_LNUMBER,
                                 T_DNUMBER,
                                 T_STRING,
                                 T_WHITESPACE,
+                                T_THIS,
+                                T_OBJECT_OPERATOR,
+                                T_OPEN_SQUARE_BRACKET,
+                                T_CLOSE_SQUARE_BRACKET,
+                                T_MODULUS,
                                );
 
                     for ($prev = ($stackPtr - 1); $prev > $bracket; $prev--) {
@@ -163,7 +174,10 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 if (in_array($prevCode, PHP_CodeSniffer_Tokens::$scopeOpeners) === true) {
                     // This operation is inside an a control structure like FOREACH
                     // or IF, but has no bracket of it's own.
-                    break;
+                    // The only control structure allowed to do this is SWITCH.
+                    if ($prevCode !== T_SWITCH) {
+                        break;
+                    }
                 }
 
                 if ($prevCode === T_OPEN_PARENTHESIS) {
@@ -187,13 +201,14 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 // part of an arithmetic operation.
                 $invalidTokens = array(
                                   T_COMMA,
+                                  T_COLON,
                                   T_OPEN_PARENTHESIS,
                                   T_OPEN_SQUARE_BRACKET,
                                  );
 
                 if (in_array($tokens[$previousToken]['code'], $invalidTokens) === false) {
                     $error = 'Arithmetic operation must be bracketed';
-                    $phpcsFile->addError($error, $stackPtr);
+                    $phpcsFile->addError($error, $stackPtr, 'MissingBrackets');
                 }
 
                 return;
@@ -201,7 +216,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
         } else if ($tokens[$lastBracket]['parenthesis_closer'] < $stackPtr) {
             // There are a set of brackets in front of it that don't include it.
             $error = 'Arithmetic operation must be bracketed';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'MissingBrackets');
             return;
         } else {
             // We are enclosed in a set of bracket, so the last thing to
@@ -217,7 +232,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
                 $closeSquareBracket = $phpcsFile->findNext($brackets, ($stackPtr + 1));
                 if ($closeSquareBracket !== false && $tokens[$closeSquareBracket]['code'] === T_CLOSE_SQUARE_BRACKET) {
                     $error = 'Arithmetic operation must be bracketed';
-                    $phpcsFile->addError($error, $stackPtr);
+                    $phpcsFile->addError($error, $stackPtr, 'MissingBrackets');
                 }
             }
 
@@ -227,7 +242,7 @@ class Squiz_Sniffs_Formatting_OperatorBracketSniff implements PHP_CodeSniffer_Sn
         $lastAssignment = $phpcsFile->findPrevious(PHP_CodeSniffer_Tokens::$assignmentTokens, $stackPtr, null, false, null, true);
         if ($lastAssignment !== false && $lastAssignment > $lastBracket) {
             $error = 'Arithmetic operation must be bracketed';
-            $phpcsFile->addError($error, $stackPtr);
+            $phpcsFile->addError($error, $stackPtr, 'MissingBrackets');
         }
 
     }//end process()
