@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: FunctionDeclarationArgumentSpacingSniff.php,v 1.10 2007/10/19 07:05:35 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements PHP_CodeSniffer_Sniff
@@ -61,6 +60,8 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
         $openBracket  = $tokens[$stackPtr]['parenthesis_opener'];
         $closeBracket = $tokens[$stackPtr]['parenthesis_closer'];
 
+        $multiLine = ($tokens[$openBracket]['line'] !== $tokens[$closeBracket]['line']);
+
         $nextParam = $openBracket;
         $params    = array();
         while (($nextParam = $phpcsFile->findNext(T_VARIABLE, ($nextParam + 1), $closeBracket)) !== false) {
@@ -75,17 +76,21 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
             if ($nextCode === T_EQUAL) {
                 // Check parameter default spacing.
                 if (($nextToken - $nextParam) > 1) {
-                    $gap   = strlen($tokens[($nextParam + 1)]['content']);
-                    $arg   = $tokens[$nextParam]['content'];
-                    $error = "Expected 0 spaces between argument \"$arg\" and equals sign; $gap found";
-                    $phpcsFile->addError($error, $nextToken);
+                    $error = 'Expected 0 spaces between argument "%s" and equals sign; %s found';
+                    $data  = array(
+                              $tokens[$nextParam]['content'],
+                              strlen($tokens[($nextParam + 1)]['content']),
+                             );
+                    $phpcsFile->addError($error, $nextToken, 'SpaceBeforeEquals', $data);
                 }
 
                 if ($tokens[($nextToken + 1)]['code'] === T_WHITESPACE) {
-                    $gap   = strlen($tokens[($nextToken + 1)]['content']);
-                    $arg   = $tokens[$nextParam]['content'];
-                    $error = "Expected 0 spaces between default value and equals sign for argument \"$arg\"; $gap found";
-                    $phpcsFile->addError($error, $nextToken);
+                    $error = 'Expected 0 spaces between default value and equals sign for argument "%s"; %s found';
+                    $data  = array(
+                              $tokens[$nextParam]['content'],
+                              strlen($tokens[($nextToken + 1)]['content']),
+                             );
+                    $phpcsFile->addError($error, $nextToken, 'SpaceAfterDefault', $data);
                 }
             }
 
@@ -94,10 +99,12 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
             if ($nextComma !== false) {
                 // Comma found.
                 if ($tokens[($nextComma - 1)]['code'] === T_WHITESPACE) {
-                    $space = strlen($tokens[($nextComma - 1)]['content']);
-                    $arg   = $tokens[$nextParam]['content'];
-                    $error = "Expected 0 spaces between argument \"$arg\" and comma; $space found";
-                    $phpcsFile->addError($error, $nextToken);
+                    $error = 'Expected 0 spaces between argument "%s" and comma; %s found';
+                    $data  = array(
+                              $tokens[$nextParam]['content'],
+                              strlen($tokens[($nextComma - 1)]['content']),
+                             );
+                    $phpcsFile->addError($error, $nextToken, 'SpaceBeforeComma', $data);
                 }
             }
 
@@ -129,27 +136,43 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
                         $hint = $tokens[$nextToken]['content'];
 
                         if ($gap !== 1) {
-                            $error = "Expected 1 space between type hint and argument \"$arg\"; $gap found";
-                            $phpcsFile->addError($error, $nextToken);
+                            $error = 'Expected 1 space between type hint and argument "%s"; %s found';
+                            $data  = array(
+                                      $arg,
+                                      $gap,
+                                     );
+                            $phpcsFile->addError($error, $nextToken, 'SpacingAfterHint', $data);
                         }
 
-                        if ($tokens[($comma + 1)]['code'] !== T_WHITESPACE) {
-                            $error = "Expected 1 space between comma and type hint \"$hint\"; 0 found";
-                            $phpcsFile->addError($error, $nextToken);
-                        } else {
-                            $gap = strlen($tokens[($comma + 1)]['content']);
-                            if ($gap !== 1) {
-                                $error = "Expected 1 space between comma and type hint \"$hint\"; $gap found";
-                                $phpcsFile->addError($error, $nextToken);
+                        if ($multiLine === false) {
+                            if ($tokens[($comma + 1)]['code'] !== T_WHITESPACE) {
+                                $error = 'Expected 1 space between comma and type hint "%s"; 0 found';
+                                $data  = array($hint);
+                                $phpcsFile->addError($error, $nextToken, 'NoSapceBeforeHint', $data);
+                            } else {
+                                $gap = strlen($tokens[($comma + 1)]['content']);
+                                if ($gap !== 1) {
+                                    $error = 'Expected 1 space between comma and type hint "%s"; %s found';
+                                    $data  = array(
+                                              $hint,
+                                              $gap,
+                                             );
+                                    $phpcsFile->addError($error, $nextToken, 'SpacingBeforeHint', $data);
+                                }
                             }
                         }
-                    } else if ($gap !== 1) {
-                        $error = "Expected 1 space between comma and argument \"$arg\"; $gap found";
-                        $phpcsFile->addError($error, $nextToken);
+                    } else if ($multiLine === false && $gap !== 1) {
+                        $error = 'Expected 1 space between comma and argument "%s"; %s found';
+                        $data  = array(
+                                  $arg,
+                                  $gap,
+                                 );
+                        $phpcsFile->addError($error, $nextToken, 'SpacingBeforeArg', $data);
                     }//end if
                 } else {
-                    $error = "Expected 1 space between comma and argument \"$arg\"; 0 found";
-                    $phpcsFile->addError($error, $nextToken);
+                    $error = 'Expected 1 space between comma and argument "%s"; 0 found';
+                    $data  = array($arg);
+                    $phpcsFile->addError($error, $nextToken, 'NoSpaceBeforeArg', $data);
                 }//end if
             } else {
                 // First argument in function declaration.
@@ -170,18 +193,31 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
                         $hint = $tokens[$nextToken]['content'];
 
                         if ($gap !== 1) {
-                            $error = "Expected 1 space between type hint and argument \"$arg\"; $gap found";
-                            $phpcsFile->addError($error, $nextToken);
+                            $error = 'Expected 1 space between type hint and argument "%s"; %s found';
+                            $data  = array(
+                                      $arg,
+                                      $gap,
+                                     );
+                            $phpcsFile->addError($error, $nextToken, 'SpacingAfterHint', $data);
                         }
 
-                        if ($tokens[($bracket + 1)]['code'] === T_WHITESPACE) {
-                            $gap   = strlen($tokens[($bracket + 1)]['content']);
-                            $error = "Expected 0 spaces between opening bracket and type hint \"$hint\"; $gap found";
-                            $phpcsFile->addError($error, $nextToken);
+                        if ($multiLine === false
+                            && $tokens[($bracket + 1)]['code'] === T_WHITESPACE
+                        ) {
+                            $error = 'Expected 0 spaces between opening bracket and type hint "%s"; %s found';
+                            $data  = array(
+                                      $hint,
+                                      strlen($tokens[($bracket + 1)]['content']),
+                                     );
+                            $phpcsFile->addError($error, $nextToken, 'SpacingAfterOpenHint', $data);
                         }
-                    } else {
-                        $error = "Expected 0 spaces between opening bracket and argument \"$arg\"; $gap found";
-                        $phpcsFile->addError($error, $nextToken);
+                    } else if ($multiLine === false) {
+                        $error = 'Expected 0 spaces between opening bracket and argument "%s"; %s found';
+                        $data  = array(
+                                      $arg,
+                                      $gap,
+                                     );
+                        $phpcsFile->addError($error, $nextToken, 'SpacingAfterOpen', $data);
                     }
                 }//end if
             }//end if
@@ -193,16 +229,20 @@ class Squiz_Sniffs_Functions_FunctionDeclarationArgumentSpacingSniff implements
         if (empty($params) === true) {
             // There are no parameters for this function.
             if (($closeBracket - $openBracket) !== 1) {
-                $space = strlen($tokens[($closeBracket - 1)]['content']);
-                $error = "Expected 0 spaces between brackets of function declaration; $space found";
-                $phpcsFile->addError($error, $stackPtr);
+                $error = 'Expected 0 spaces between brackets of function declaration; %s found';
+                $data  = array(strlen($tokens[($closeBracket - 1)]['content']));
+                $phpcsFile->addError($error, $stackPtr, 'SpacingBetween', $data);
             }
-        } else if ($tokens[($closeBracket - 1)]['code'] === T_WHITESPACE) {
+        } else if ($multiLine === false
+            && $tokens[($closeBracket - 1)]['code'] === T_WHITESPACE
+        ) {
             $lastParam = array_pop($params);
-            $arg       = $tokens[$lastParam]['content'];
-            $gap       = strlen($tokens[($closeBracket - 1)]['content']);
-            $error     = "Expected 0 spaces between argument \"$arg\" and closing bracket; $gap found";
-            $phpcsFile->addError($error, $closeBracket);
+            $error     = 'Expected 0 spaces between argument "%s" and closing bracket; %s found';
+            $data      = array(
+                          $tokens[$lastParam]['content'],
+                          strlen($tokens[($closeBracket - 1)]['content']),
+                         );
+            $phpcsFile->addError($error, $closeBracket, 'SpacingBeforeClose', $data);
         }
 
     }//end process()
