@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: CommentedOutCodeSniff.php,v 1.9 2008/02/14 23:16:34 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,20 +22,30 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'CSS',
+                                  );
+
     /**
      * If a comment is more than $maxPercentage% code, a warning will be shown.
      *
      * @var int
      */
-    protected $maxPercentage = 45;
+    public $maxPercentage = 35;
 
 
     /**
@@ -69,7 +78,16 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
             return;
         }
 
-        $content = '<?php ';
+        // Ignore comments at the end of code blocks.
+        if (substr($tokens[$stackPtr]['content'], 0, 6) === '//end ') {
+            return;
+        }
+
+        $content = '';
+        if ($phpcsFile->tokenizerType === 'PHP') {
+            $content = '<?php ';
+        }
+
         for ($i = $stackPtr; $i < $phpcsFile->numTokens; $i++) {
             if ($tokens[$stackPtr]['code'] !== $tokens[$i]['code']) {
                 break;
@@ -109,7 +127,15 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
             $content .= $tokenContent.$phpcsFile->eolChar;
         }//end for
 
-        $content = trim($content).' ?>';
+        $content = trim($content);
+
+        if ($phpcsFile->tokenizerType === 'PHP') {
+            $content .= ' ?>';
+        }
+
+        // Quite a few comments use multiple dashes, equals signs etc
+        // to frame comments and licence headers.
+        $content = preg_replace('/[-=*]+/', '-', $content);
 
         $stringTokens = PHP_CodeSniffer_File::tokenizeString($content, $phpcsFile->tokenizer, $phpcsFile->eolChar);
 
@@ -118,6 +144,7 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
                         T_STRING,
                         T_STRING_CONCAT,
                         T_ENCAPSED_AND_WHITESPACE,
+                        T_NONE,
                        );
 
         $numTokens = count($stringTokens);
@@ -174,8 +201,9 @@ class Squiz_Sniffs_PHP_CommentedOutCodeSniff implements PHP_CodeSniffer_Sniff
             // Just in case.
             $percentCode = min(100, $percentCode);
 
-            $error = "This comment is ${percentCode}% valid code; is this commented out code?";
-            $phpcsFile->addWarning($error, $stackPtr);
+            $error = 'This comment is %s%% valid code; is this commented out code?';
+            $data  = array($percentCode);
+            $phpcsFile->addWarning($error, $stackPtr, 'Found', $data);
         }
 
     }//end process()
