@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: GlobalKeywordSniff.php,v 1.2 2007/07/23 01:47:53 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_GlobalKeywordSniff implements PHP_CodeSniffer_Sniff
@@ -59,8 +58,9 @@ class Squiz_Sniffs_PHP_GlobalKeywordSniff implements PHP_CodeSniffer_Sniff
 
         $nextVar = $tokens[$phpcsFile->findNext(array(T_VARIABLE), $stackPtr)];
         $varName = str_replace('$', '', $nextVar['content']);
-        $error   = "Use of the \"global\" keyword is forbidden; use \"\$GLOBALS['$varName']\" instead";
-        $phpcsFile->addError($error, $stackPtr);
+        $error   = 'Use of the "global" keyword is forbidden; use "$GLOBALS[\'%s\']" instead';
+        $data    = array($varName);
+        $phpcsFile->addError($error, $stackPtr, 'NotAllowed', $data);
 
     }//end process()
 
