@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: HeredocSniff.php,v 1.2 2007/07/23 01:47:53 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_PHP_HeredocSniff implements PHP_CodeSniffer_Sniff
@@ -39,7 +38,10 @@ class Squiz_Sniffs_PHP_HeredocSniff implements PHP_CodeSniffer_Sniff
      */
     public function register()
     {
-        return array(T_START_HEREDOC);
+        return array(
+                T_START_HEREDOC,
+                T_START_NOWDOC,
+               );
 
     }//end register()
 
@@ -55,8 +57,8 @@ class Squiz_Sniffs_PHP_HeredocSniff implements PHP_CodeSniffer_Sniff
      */
     public function process(PHP_CodeSniffer_File $phpcsFile, $stackPtr)
     {
-        $error = 'Use of heredoc syntax ("<<<") is not allowed; use standard strings or inline HTML instead';
-        $phpcsFile->addError($error, $stackPtr);
+        $error = 'Use of heredoc and nowdoc syntax ("<<<") is not allowed; use standard strings or inline HTML instead';
+        $phpcsFile->addError($error, $stackPtr, 'NotAllowed');
 
     }//end process()
 
