@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: DoubleQuoteUsageSniff.php,v 1.5 2008/03/20 03:42:35 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Sniff
@@ -41,6 +40,7 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
     {
         return array(
                 T_CONSTANT_ENCAPSED_STRING,
+                T_DOUBLE_QUOTED_STRING,
                );
 
     }//end register()
@@ -50,8 +50,8 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
      * Processes this test, when one of its tokens is encountered.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
-     * @param int                  $stackPtr  The position of the current token in the
-     *                                        stack passed in $tokens.
+     * @param int                  $stackPtr  The position of the current token
+     *                                        in the stack passed in $tokens.
      *
      * @return void
      */
@@ -59,19 +59,43 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
     {
         $tokens = $phpcsFile->getTokens();
 
+        // We are only interested in the first token in a multi-line string.
+        if ($tokens[$stackPtr]['code'] === $tokens[($stackPtr - 1)]['code']) {
+            return;
+        }
+
         $workingString = $tokens[$stackPtr]['content'];
+        $i = ($stackPtr + 1);
+        while ($tokens[$i]['code'] === $tokens[$stackPtr]['code']) {
+            $workingString .= $tokens[$i]['content'];
+            $i++;
+        }
 
         // Check if it's a double quoted string.
         if (strpos($workingString, '"') === false) {
             return;
         }
 
-        // Make sure it's not a part of a string started above.
+        // Make sure it's not a part of a string started in a previous line.
         // If it is, then we have already checked it.
         if ($workingString[0] !== '"') {
             return;
         }
 
+        // The use of variables in double quoted strings is not allowed.
+        if ($tokens[$stackPtr]['code'] === T_DOUBLE_QUOTED_STRING) {
+            $stringTokens = token_get_all('<?php '.$workingString);
+            foreach ($stringTokens as $token) {
+                if (is_array($token) === true && $token[0] === T_VARIABLE) {
+                    $error = 'Variable "%s" not allowed in double quoted string; use concatenation instead';
+                    $data  = array($token[1]);
+                    $phpcsFile->addError($error, $stackPtr, 'ContainsVar', $data);
+                }
+            }
+
+            return;
+        }//end if
+
         // Work through the following tokens, in case this string is stretched
         // over multiple Lines.
         for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
@@ -83,6 +107,7 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
         }
 
         $allowedChars = array(
+                         '\0',
                          '\n',
                          '\r',
                          '\f',
@@ -98,8 +123,9 @@ class Squiz_Sniffs_Strings_DoubleQuoteUsageSniff implements PHP_CodeSniffer_Snif
             }
         }
 
-        $error = "String $workingString does not require double quotes; use single quotes instead";
-        $phpcsFile->addError($error, $stackPtr);
+        $error = 'String %s does not require double quotes; use single quotes instead';
+        $data  = array($workingString);
+        $phpcsFile->addError($error, $stackPtr, 'NotRequired', $data);
 
     }//end process()
 
