@@ -8,29 +8,38 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: ControlStructureSpacingSniff.php,v 1.7 2008/02/20 22:35:16 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
 /**
  * Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff.
  *
- * Checks that any array declarations are lower case.
+ * Checks that control structures have the correct spacing around brackets.
  *
  * @category  PHP
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -57,8 +66,8 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
      * Processes this test, when one of its tokens is encountered.
      *
      * @param PHP_CodeSniffer_File $phpcsFile The file being scanned.
-     * @param int                  $stackPtr  The position of the current token in the
-     *                                        stack passed in $tokens.
+     * @param int                  $stackPtr  The position of the current token
+     *                                        in the stack passed in $tokens.
      *
      * @return void
      */
@@ -70,16 +79,68 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
             return;
         }
 
-        $scopeCloser = $tokens[$stackPtr]['scope_closer'];
-        $scopeOpener = $tokens[$stackPtr]['scope_opener'];
+        if (isset($tokens[$stackPtr]['parenthesis_opener']) === true) {
+            $parenOpener = $tokens[$stackPtr]['parenthesis_opener'];
+            $parenCloser = $tokens[$stackPtr]['parenthesis_closer'];
+            if ($tokens[($parenOpener + 1)]['code'] === T_WHITESPACE) {
+                $gap   = strlen($tokens[($parenOpener + 1)]['content']);
+                $error = 'Expected 0 spaces after opening bracket; %s found';
+                $data  = array($gap);
+                $phpcsFile->addError($error, ($parenOpener + 1), 'SpacingAfterOpenBrace', $data);
+            }
 
-        $firstContent = $phpcsFile->findNext(T_WHITESPACE, ($scopeOpener + 1), null, true);
-        if ($tokens[$firstContent]['line'] !== ($tokens[$stackPtr]['line'] + 1)) {
+            if ($tokens[$parenOpener]['line'] === $tokens[$parenCloser]['line']
+                && $tokens[($parenCloser - 1)]['code'] === T_WHITESPACE
+            ) {
+                $gap   = strlen($tokens[($parenCloser - 1)]['content']);
+                $error = 'Expected 0 spaces before closing bracket; %s found';
+                $data  = array($gap);
+                $phpcsFile->addError($error, ($parenCloser - 1), 'SpaceBeforeCloseBrace', $data);
+            }
+        }//end if
+
+        $scopeOpener = $tokens[$stackPtr]['scope_opener'];
+        $scopeCloser = $tokens[$stackPtr]['scope_closer'];
+
+        $firstContent = $phpcsFile->findNext(
+            T_WHITESPACE,
+            ($scopeOpener + 1),
+            null,
+            true
+        );
+
+        if ($tokens[$firstContent]['line'] !== ($tokens[$scopeOpener]['line'] + 1)) {
             $error = 'Blank line found at start of control structure';
-            $phpcsFile->addError($error, $scopeOpener);
+            $phpcsFile->addError($error, $scopeOpener, 'SpacingBeforeOpen');
         }
 
-        $trailingContent = $phpcsFile->findNext(T_WHITESPACE, ($scopeCloser + 1), null, true);
+        $lastContent = $phpcsFile->findPrevious(
+            T_WHITESPACE,
+            ($scopeCloser - 1),
+            null,
+            true
+        );
+
+        if ($tokens[$lastContent]['line'] !== ($tokens[$scopeCloser]['line'] - 1)) {
+            $errorToken = $scopeCloser;
+            for ($i = ($scopeCloser - 1); $i > $lastContent; $i--) {
+                if ($tokens[$i]['line'] < $tokens[$scopeCloser]['line']) {
+                    $errorToken = $i;
+                    break;
+                }
+            }
+
+            $error = 'Blank line found at end of control structure';
+            $phpcsFile->addError($error, $errorToken, 'SpacingAfterClose');
+        }
+
+        $trailingContent = $phpcsFile->findNext(
+            T_WHITESPACE,
+            ($scopeCloser + 1),
+            null,
+            true
+        );
+
         if ($tokens[$trailingContent]['code'] === T_ELSE) {
             if ($tokens[$stackPtr]['code'] === T_IF) {
                 // IF with ELSE.
@@ -92,7 +153,12 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
                 if (substr($tokens[$trailingContent]['content'], 0, 5) === '//end') {
                     // There is an end comment, so we have to get the next piece
                     // of content.
-                    $trailingContent = $phpcsFile->findNext(T_WHITESPACE, ($trailingContent + 1), null, true);
+                    $trailingContent = $phpcsFile->findNext(
+                        T_WHITESPACE,
+                        ($trailingContent + 1),
+                        null,
+                        true
+                    );
                 }
             }
         }
@@ -102,7 +168,9 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
             // blank line after this control structure.
             if (isset($tokens[$trailingContent]['scope_condition']) === true) {
                 $condition = $tokens[$trailingContent]['scope_condition'];
-                if ($tokens[$condition]['code'] === T_CASE || $tokens[$condition]['code'] === T_DEFAULT) {
+                if ($tokens[$condition]['code'] === T_CASE
+                    || $tokens[$condition]['code'] === T_DEFAULT
+                ) {
                     return;
                 }
             }
@@ -126,12 +194,12 @@ class Squiz_Sniffs_WhiteSpace_ControlStructureSpacingSniff implements PHP_CodeSn
 
             if ($tokens[$trailingContent]['line'] !== ($tokens[$scopeCloser]['line'] + 1)) {
                 $error = 'Blank line found after control structure';
-                $phpcsFile->addError($error, $scopeCloser);
+                $phpcsFile->addError($error, $scopeCloser, 'LineAfterClose');
             }
         } else {
             if ($tokens[$trailingContent]['line'] === ($tokens[$scopeCloser]['line'] + 1)) {
                 $error = 'No blank line found after control structure';
-                $phpcsFile->addError($error, $scopeCloser);
+                $phpcsFile->addError($error, $scopeCloser, 'NoLineAfterClose');
             }
         }
 
