@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: FunctionClosingBraceSpaceSniff.php,v 1.8 2007/10/23 05:14:03 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,14 +22,24 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_FunctionClosingBraceSpaceSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -65,13 +74,38 @@ class Squiz_Sniffs_WhiteSpace_FunctionClosingBraceSpaceSniff implements PHP_Code
         $closeBrace  = $tokens[$stackPtr]['scope_closer'];
         $prevContent = $phpcsFile->findPrevious(T_WHITESPACE, ($closeBrace - 1), null, true);
 
+        // Special case for empty JS functions
+        if ($phpcsFile->tokenizerType === 'JS' && $prevContent === $tokens[$stackPtr]['scope_opener']) {
+            // In this case, the opening and closing brace must be
+            // right next to each other.
+            if ($tokens[$stackPtr]['scope_closer'] !== ($tokens[$stackPtr]['scope_opener'] + 1)) {
+                $error = 'The opening and closing braces of empty functions must be directly next to each other; e.g., function () {}';
+                $phpcsFile->addError($error, $closeBrace, 'SpacingBetween');
+            }
+
+            return;
+        }
+
         $braceLine = $tokens[$closeBrace]['line'];
         $prevLine  = $tokens[$prevContent]['line'];
 
         $found = ($braceLine - $prevLine - 1);
-        if ($found !== 1) {
-            $error = "Expected 1 blank line before closing function brace; $found found";
-            $phpcsFile->addError($error, $closeBrace);
+        if ($phpcsFile->hasCondition($stackPtr, T_FUNCTION) === true || isset($tokens[$stackPtr]['nested_parenthesis']) === true) {
+            // Nested function.
+            if ($found < 0) {
+                $error = 'Closing brace of nested function must be on a new line';
+                $phpcsFile->addError($error, $closeBrace, 'ContentBeforeClose');
+            } else if ($found > 0) {
+                $error = 'Expected 0 blank lines before closing brace of nested function; %s found';
+                $data  = array($found);
+                $phpcsFile->addError($error, $closeBrace, 'SpacingBeforeNestedClose', $data);
+            }
+        } else {
+            if ($found !== 1) {
+                $error = 'Expected 1 blank line before closing function brace; %s found';
+                $data  = array($found);
+                $phpcsFile->addError($error, $closeBrace, 'SpacingBeforeClose', $data);
+            }
         }
 
     }//end process()
