@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: FunctionOpeningBraceSpaceSniff.php,v 1.4 2007/10/23 05:14:03 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,14 +22,24 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_FunctionOpeningBraceSpaceSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                  );
+
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -76,11 +85,41 @@ class Squiz_Sniffs_WhiteSpace_FunctionOpeningBraceSpaceSniff implements PHP_Code
         $nextLine  = $tokens[$nextContent]['line'];
 
         $found = ($nextLine - $braceLine - 1);
-        if ($found !== 0) {
-            $error = "Expected 0 blank lines after opening function brace; $found found";
-            $phpcsFile->addError($error, $openBrace);
+        if ($found > 0) {
+            $error = 'Expected 0 blank lines after opening function brace; %s found';
+            $data  = array($found);
+            $phpcsFile->addError($error, $openBrace, 'SpacingAfter', $data);
         }
 
+        if ($phpcsFile->tokenizerType === 'JS') {
+            // Do some additional checking before the function brace.
+            $nestedFunction = ($phpcsFile->hasCondition($stackPtr, T_FUNCTION) === true || isset($tokens[$stackPtr]['nested_parenthesis']) === true);
+
+            $functionLine   = $tokens[$tokens[$stackPtr]['parenthesis_closer']]['line'];
+            $lineDifference = ($braceLine - $functionLine);
+
+            if ($nestedFunction === true) {
+                if ($lineDifference > 0) {
+                    $error = 'Expected 0 blank lines before opening brace of nested function; %s found';
+                    $data  = array($found);
+                    $phpcsFile->addError($error, $openBrace, 'SpacingAfterNested', $data);
+                }
+            } else {
+                if ($lineDifference === 0) {
+                    $error = 'Opening brace should be on a new line';
+                    $phpcsFile->addError($error, $openBrace, 'ContentBefore');
+                    return;
+                }
+
+                if ($lineDifference > 1) {
+                    $error = 'Opening brace should be on the line after the declaration; found %s blank line(s)';
+                    $data  = array(($lineDifference - 1));
+                    $phpcsFile->addError($error, $openBrace, 'SpacingBefore', $data);
+                    return;
+                }
+            }//end if
+        }//end if
+
     }//end process()
 
 
