@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: SuperfluousWhitespaceSniff.php,v 1.8 2008/02/01 00:26:39 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -25,14 +24,24 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Sniffs_WhiteSpace_SuperfluousWhitespaceSniff implements PHP_CodeSniffer_Sniff
 {
 
+    /**
+     * A list of tokenizers this sniff supports.
+     *
+     * @var array
+     */
+    public $supportedTokenizers = array(
+                                   'PHP',
+                                   'JS',
+                                   'CSS',
+                                  );
 
     /**
      * Returns an array of tokens this test wants to listen for.
@@ -70,25 +79,35 @@ class Squiz_Sniffs_WhiteSpace_SuperfluousWhitespaceSniff implements PHP_CodeSnif
                 Check for start of file whitespace.
             */
 
-            // If its the first token, then there is no space.
-            if ($stackPtr === 0) {
-                return;
-            }
-
-            for ($i = ($stackPtr - 1); $i >= 0; $i--) {
-                // If we find something that isn't inline html then there is something previous in the file.
-                if ($tokens[$i]['type'] !== 'T_INLINE_HTML') {
+            if ($phpcsFile->tokenizerType !== 'PHP') {
+                // The first token is always the open tag inserted when tokenizsed
+                // and the second token is always the first piece of content in
+                // the file. If the second token is whitespace, there was
+                // whitespace at the start of the file.
+                if ($tokens[($stackPtr + 1)]['code'] !== T_WHITESPACE) {
+                    return;
+                }
+            } else {
+                // If its the first token, then there is no space.
+                if ($stackPtr === 0) {
                     return;
                 }
 
-                // If we have ended up with inline html make sure it isn't just whitespace.
-                $tokenContent = trim($tokens[$i]['content']);
-                if ($tokenContent !== '') {
-                    return;
-                }
-            }
+                for ($i = ($stackPtr - 1); $i >= 0; $i--) {
+                    // If we find something that isn't inline html then there is something previous in the file.
+                    if ($tokens[$i]['type'] !== 'T_INLINE_HTML') {
+                        return;
+                    }
 
-            $phpcsFile->addError('Additional whitespace found at start of file', $stackPtr);
+                    // If we have ended up with inline html make sure it isn't just whitespace.
+                    $tokenContent = trim($tokens[$i]['content']);
+                    if ($tokenContent !== '') {
+                        return;
+                    }
+                }
+            }//end if
+
+            $phpcsFile->addError('Additional whitespace found at start of file', $stackPtr, 'StartFile');
 
         } else if ($tokens[$stackPtr]['code'] === T_CLOSE_TAG) {
 
@@ -96,27 +115,48 @@ class Squiz_Sniffs_WhiteSpace_SuperfluousWhitespaceSniff implements PHP_CodeSnif
                 Check for end of file whitespace.
             */
 
-            if (isset($tokens[($stackPtr + 1)]) === false) {
-                // The close PHP token is the last in the file.
-                return;
-            }
-
-            for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
-                // If we find something that isn't inline html then there
-                // is more to the file.
-                if ($tokens[$i]['type'] !== 'T_INLINE_HTML') {
+            if ($phpcsFile->tokenizerType === 'JS') {
+                // The last token is always the close tag inserted when tokenizsed
+                // and the second last token is always the last piece of content in
+                // the file. If the second last token is whitespace, there was
+                // whitespace at the end of the file.
+                if ($tokens[($stackPtr - 1)]['code'] !== T_WHITESPACE) {
+                    return;
+                }
+            } else if ($phpcsFile->tokenizerType === 'CSS') {
+                // The last two tokens are always the close tag and whitespace
+                // inserted when tokenizsed and the third last token is always the
+                // last piece of content in the file. If the third last token is
+                // whitespace, there was whitespace at the end of the file.
+                if ($tokens[($stackPtr - 3)]['code'] !== T_WHITESPACE) {
                     return;
                 }
 
-                // If we have ended up with inline html make sure it
-                // isn't just whitespace.
-                $tokenContent = trim($tokens[$i]['content']);
-                if (empty($tokenContent) === false) {
+                // Adjust the pointer to give the correct line number for the error.
+                $stackPtr -= 2;
+            } else {
+                if (isset($tokens[($stackPtr + 1)]) === false) {
+                    // The close PHP token is the last in the file.
                     return;
                 }
+
+                for ($i = ($stackPtr + 1); $i < $phpcsFile->numTokens; $i++) {
+                    // If we find something that isn't inline html then there
+                    // is more to the file.
+                    if ($tokens[$i]['type'] !== 'T_INLINE_HTML') {
+                        return;
+                    }
+
+                    // If we have ended up with inline html make sure it
+                    // isn't just whitespace.
+                    $tokenContent = trim($tokens[$i]['content']);
+                    if (empty($tokenContent) === false) {
+                        return;
+                    }
+                }
             }
 
-            $phpcsFile->addError('Additional whitespace found at end of file', $stackPtr);
+            $phpcsFile->addError('Additional whitespace found at end of file', $stackPtr, 'EndFile');
 
         } else {
 
@@ -131,7 +171,7 @@ class Squiz_Sniffs_WhiteSpace_SuperfluousWhitespaceSniff implements PHP_CodeSnif
             $tokenContent = rtrim($tokens[$stackPtr]['content'], $phpcsFile->eolChar);
             if (empty($tokenContent) === false) {
                 if (preg_match('|^.*\s+$|', $tokenContent) !== 0) {
-                    $phpcsFile->addError('Whitespace found at end of line', $stackPtr);
+                    $phpcsFile->addError('Whitespace found at end of line', $stackPtr, 'EndLine');
                 }
             }
 
@@ -147,8 +187,9 @@ class Squiz_Sniffs_WhiteSpace_SuperfluousWhitespaceSniff implements PHP_CodeSnif
                     $next  = $phpcsFile->findNext(T_WHITESPACE, $stackPtr, null, true);
                     $lines = $tokens[$next]['line'] - $tokens[$stackPtr]['line'];
                     if ($lines > 1) {
-                        $error = "Functions must not contain multiple empty lines in a row; found $lines empty lines";
-                        $phpcsFile->addError($error, $stackPtr);
+                        $error = 'Functions must not contain multiple empty lines in a row; found %s empty lines';
+                        $data  = array($lines);
+                        $phpcsFile->addError($error, $stackPtr, 'EmptyLines', $data);
                     }
                 }
             }
