@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: PostStatementCommentUnitTest.php,v 1.1 2006/12/18 23:39:25 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_Commenting_PostStatementCommentUnitTest extends AbstractSniffUnitTest
@@ -39,15 +38,31 @@ class Squiz_Tests_Commenting_PostStatementCommentUnitTest extends AbstractSniffU
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='PostStatementCommentUnitTest.inc')
     {
-        return array(
-                6  => 1,
-                10 => 1,
-                18 => 1,
-               );
+        switch ($testFile) {
+        case 'PostStatementCommentUnitTest.inc':
+            return array(
+                    6  => 1,
+                    10 => 1,
+                    18 => 1,
+                   );
+            break;
+        case 'PostStatementCommentUnitTest.js':
+            return array(
+                    1 => 1,
+                    4 => 1,
+                    9 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
