@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: CommentedOutCodeUnitTest.php,v 1.1 2007/10/22 23:00:08 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_PHP_CommentedOutCodeUnitTest extends AbstractSniffUnitTest
@@ -56,14 +55,27 @@ class Squiz_Tests_PHP_CommentedOutCodeUnitTest extends AbstractSniffUnitTest
      *
      * @return array(int => int)
      */
-    public function getWarningList()
+    public function getWarningList($testFile='CommentedOutCodeUnitTest.inc')
     {
-        return array(
-                6  => 1,
-                8  => 1,
-                15 => 1,
-                19 => 1,
-               );
+        switch ($testFile) {
+        case 'CommentedOutCodeUnitTest.inc':
+            return array(
+                    6  => 1,
+                    8  => 1,
+                    15 => 1,
+                    19 => 1,
+                   );
+            break;
+        case 'CommentedOutCodeUnitTest.css':
+            return array(
+                    7  => 1,
+                    16 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getWarningList()
 
