@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: DisallowInlineIfUnitTest.php,v 1.1 2007/11/29 04:07:25 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_PHP_DisallowInlineIfUnitTest extends AbstractSniffUnitTest
@@ -41,11 +40,23 @@ class Squiz_Tests_PHP_DisallowInlineIfUnitTest extends AbstractSniffUnitTest
      *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='DisallowInlineIfUnitTest.inc')
     {
-        return array(
-                8 => 1,
-               );
+        switch ($testFile) {
+        case 'DisallowInlineIfUnitTest.inc':
+            return array(
+                    8 => 1,
+                   );
+            break;
+        case 'DisallowInlineIfUnitTest.js':
+            return array(
+                    1 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
