@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: SemicolonSpacingUnitTest.php,v 1.2 2007/10/09 01:25:21 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_WhiteSpace_SemicolonSpacingUnitTest extends AbstractSniffUnitTest
@@ -39,18 +38,37 @@ class Squiz_Tests_WhiteSpace_SemicolonSpacingUnitTest extends AbstractSniffUnitT
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='SemicolonSpacingUnitTest.inc')
     {
-        return array(
-                3 => 1,
-                4 => 1,
-                5 => 2,
-                6 => 1,
-                8 => 1,
-                9 => 1,
-               );
+        switch ($testFile) {
+        case 'SemicolonSpacingUnitTest.inc':
+            return array(
+                    3 => 1,
+                    4 => 1,
+                    5 => 2,
+                    6 => 1,
+                    8 => 1,
+                    9 => 1,
+                   );
+            break;
+        case 'SemicolonSpacingUnitTest.js':
+            return array(
+                    3  => 1,
+                    4  => 1,
+                    6  => 1,
+                    10 => 2,
+                    11 => 1,
+                    13 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
