@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: SuperfluousWhitespaceUnitTest.php,v 1.3 2008/02/01 00:26:39 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -24,9 +23,9 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Squiz_Tests_WhiteSpace_SuperfluousWhitespaceUnitTest extends AbstractSniffUnitTest
@@ -39,21 +38,51 @@ class Squiz_Tests_WhiteSpace_SuperfluousWhitespaceUnitTest extends AbstractSniff
      * The key of the array should represent the line number and the value
      * should represent the number of errors that should occur on that line.
      *
+     * @param string $testFile The name of the file being tested.
+     *
      * @return array(int => int)
      */
-    public function getErrorList()
+    public function getErrorList($testFile='SuperfluousWhitespaceUnitTest.inc')
     {
-        return array(
-                2  => 1,
-                4  => 1,
-                5  => 1,
-                6  => 1,
-                7  => 1,
-                16 => 1,
-                23 => 1,
-                30 => 1,
-                36 => 1,
-               );
+        switch ($testFile) {
+        case 'SuperfluousWhitespaceUnitTest.inc':
+            return array(
+                    2  => 1,
+                    4  => 1,
+                    5  => 1,
+                    6  => 1,
+                    7  => 1,
+                    16 => 1,
+                    23 => 1,
+                    30 => 1,
+                    36 => 1,
+                   );
+            break;
+        case 'SuperfluousWhitespaceUnitTest.js':
+            return array(
+                    1  => 1,
+                    3  => 1,
+                    4  => 1,
+                    5  => 1,
+                    6  => 1,
+                    15 => 1,
+                    22 => 1,
+                    29 => 1,
+                    35 => 1,
+                   );
+            break;
+        case 'SuperfluousWhitespaceUnitTest.css':
+            return array(
+                    1  => 1,
+                    8  => 1,
+                    9  => 1,
+                    14 => 1,
+                   );
+            break;
+        default:
+            return array();
+            break;
+        }//end switch
 
     }//end getErrorList()
 
