@@ -9,9 +9,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: Tokens.php,v 1.16 2008/02/22 00:59:56 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -50,6 +49,39 @@ define('T_HEREDOC', 1031);
 define('T_PROTOTYPE', 1032);
 define('T_THIS', 1033);
 define('T_REGULAR_EXPRESSION', 1034);
+define('T_PROPERTY', 1035);
+define('T_LABEL', 1036);
+define('T_OBJECT', 1037);
+define('T_COLOUR', 1038);
+define('T_HASH', 1039);
+define('T_URL', 1040);
+define('T_STYLE', 1041);
+define('T_ASPERAND', 1042);
+define('T_DOLLAR', 1043);
+define('T_TYPEOF', 1044);
+define('T_CLOSURE', 1045);
+define('T_BACKTICK', 1046);
+define('T_START_NOWDOC', 1047);
+define('T_NOWDOC', 1048);
+define('T_END_NOWDOC', 1049);
+
+// Some PHP 5.3 tokens, replicated for lower versions.
+if (defined('T_NAMESPACE') === false) {
+    define('T_NAMESPACE', 1050);
+}
+
+if (defined('T_NS_SEPARATOR') === false) {
+    define('T_NS_SEPARATOR', 1051);
+}
+
+if (defined('T_GOTO') === false) {
+    define('T_GOTO', 1052);
+}
+
+// Some PHP 5.4 tokens, replicated for lower versions.
+if (defined('T_TRAIT') === false) {
+    define('T_TRAIT', 1053);
+}
 
 /**
  * The Tokens class contains weightings for tokens based on their
@@ -62,9 +94,9 @@ define('T_REGULAR_EXPRESSION', 1034);
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 final class PHP_CodeSniffer_Tokens
@@ -77,7 +109,11 @@ final class PHP_CodeSniffer_Tokens
      */
     public static $weightings = array(
                                  T_CLASS               => 1000,
+                                 T_INTERFACE           => 1000,
+                                 T_TRAIT               => 1000,
+                                 T_NAMESPACE           => 1000,
                                  T_FUNCTION            => 100,
+                                 T_CLOSURE             => 100,
 
                                  /*
                                      Conditions.
@@ -136,8 +172,6 @@ final class PHP_CodeSniffer_Tokens
                                  T_IS_NOT_IDENTICAL    => 5,
                                  T_IS_SMALLER_OR_EQUAL => 5,
                                  T_IS_GREATER_OR_EQUAL => 5,
-
-                                 T_WHITESPACE          => 0,
                                 );
 
     /**
@@ -155,6 +189,7 @@ final class PHP_CodeSniffer_Tokens
                                        T_MUL_EQUAL,
                                        T_PLUS_EQUAL,
                                        T_XOR_EQUAL,
+                                       T_DOUBLE_ARROW,
                                       );
 
     /**
@@ -223,6 +258,7 @@ final class PHP_CodeSniffer_Tokens
     public static $parenthesisOpeners = array(
                                          T_ARRAY,
                                          T_FUNCTION,
+                                         T_CLOSURE,
                                          T_WHILE,
                                          T_FOR,
                                          T_FOREACH,
@@ -240,7 +276,10 @@ final class PHP_CodeSniffer_Tokens
     public static $scopeOpeners = array(
                                    T_CLASS,
                                    T_INTERFACE,
+                                   T_TRAIT,
+                                   T_NAMESPACE,
                                    T_FUNCTION,
+                                   T_CLOSURE,
                                    T_IF,
                                    T_SWITCH,
                                    T_CASE,
@@ -283,7 +322,20 @@ final class PHP_CodeSniffer_Tokens
                                );
 
     /**
-     * Tokens that perform operations.
+     * Tokens that perform boolean operations.
+     *
+     * @var array(int)
+     */
+    public static $booleanOperators = array(
+                                       T_BOOLEAN_AND,
+                                       T_BOOLEAN_OR,
+                                       T_LOGICAL_AND,
+                                       T_LOGICAL_OR,
+                                       T_LOGICAL_XOR,
+                                      );
+
+    /**
+     * Tokens that open code blocks.
      *
      * @var array(int)
      */
@@ -326,6 +378,20 @@ final class PHP_CodeSniffer_Tokens
                                    T_DOUBLE_QUOTED_STRING,
                                   );
 
+    /**
+     * Tokens that represent brackets and parenthesis.
+     *
+     * @var array(int)
+     */
+    public static $bracketTokens = array(
+                                    T_OPEN_CURLY_BRACKET,
+                                    T_CLOSE_CURLY_BRACKET,
+                                    T_OPEN_SQUARE_BRACKET,
+                                    T_CLOSE_SQUARE_BRACKET,
+                                    T_OPEN_PARENTHESIS,
+                                    T_CLOSE_PARENTHESIS,
+                                  );
+
     /**
      * Tokens that include files.
      *
@@ -338,6 +404,17 @@ final class PHP_CodeSniffer_Tokens
                                     T_INCLUDE,
                                    );
 
+    /**
+     * Tokens that make up a heredoc string.
+     *
+     * @var array(int)
+     */
+    public static $heredocTokens = array(
+                                    T_START_HEREDOC,
+                                    T_END_HEREDOC,
+                                    T_HEREDOC,
+                                   );
+
 
     /**
      * A PHP_CodeSniffer_Tokens class cannot be constructed.
@@ -373,8 +450,14 @@ final class PHP_CodeSniffer_Tokens
         $weights = self::$weightings;
 
         foreach ($tokens as $token) {
-            if (isset($weights[$token]) === true && $weights[$token] > $highest) {
-                $highest     = $weights[$token];
+            if (isset($weights[$token]) === true) {
+                $weight = $weights[$token];
+            } else {
+                $weight = 0;
+            }
+
+            if ($weight > $highest) {
+                $highest     = $weight;
                 $highestType = $token;
             }
         }
