@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: IsCamelCapsTest.php,v 1.5 2007/08/02 00:05:40 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -23,9 +22,9 @@ require_once 'PHPUnit/Framework/TestCase.php';
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class Core_IsCamelCapsTest extends PHPUnit_Framework_TestCase
@@ -113,6 +112,7 @@ class Core_IsCamelCapsTest extends PHPUnit_Framework_TestCase
     {
         $this->assertTrue(PHP_CodeSniffer::isCamelCaps('ThisIsCamelCaps', true, true, true));
         $this->assertTrue(PHP_CodeSniffer::isCamelCaps('ThisISCamelCaps', true, true, false));
+        $this->assertTrue(PHP_CodeSniffer::isCamelCaps('This3IsCamelCaps', true, true, false));
 
     }//end testValidClassFormatPublic()
 
@@ -125,7 +125,6 @@ class Core_IsCamelCapsTest extends PHPUnit_Framework_TestCase
     public function testInvalidClassFormat()
     {
         $this->assertFalse(PHP_CodeSniffer::isCamelCaps('thisIsCamelCaps', true));
-        $this->assertFalse(PHP_CodeSniffer::isCamelCaps('This3IsCamelCaps', true));
         $this->assertFalse(PHP_CodeSniffer::isCamelCaps('This-IsCamelCaps', true));
         $this->assertFalse(PHP_CodeSniffer::isCamelCaps('This_Is_Camel_Caps', true));
 
