@@ -8,9 +8,8 @@
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   CVS: $Id: AllSniffs.php,v 1.7 2007/08/15 01:26:09 squiz Exp $
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 
@@ -30,9 +29,9 @@ require_once dirname(__FILE__).'/AbstractSniffUnitTest.php';
  * @package   PHP_CodeSniffer
  * @author    Greg Sherwood <gsherwood@squiz.net>
  * @author    Marc McIntyre <mmcintyre@squiz.net>
- * @copyright 2006 Squiz Pty Ltd (ABN 77 084 670 600)
+ * @copyright 2006-2011 Squiz Pty Ltd (ABN 77 084 670 600)
  * @license   http://matrix.squiz.net/developer/tools/php_cs/licence BSD Licence
- * @version   Release: 1.1.0
+ * @version   Release: 1.3.4
  * @link      http://pear.php.net/package/PHP_CodeSniffer
  */
 class PHP_CodeSniffer_Standards_AllSniffs
@@ -76,7 +75,7 @@ class PHP_CodeSniffer_Standards_AllSniffs
 
         foreach ($standards as $standard) {
             if ($isInstalled === false) {
-                $standardDir = realpath($standardsDir.'/'.$standard.'/Tests/');
+                $standardDir = $standardsDir.'/'.$standard.'/Tests/';
             } else {
                 $standardDir = dirname(__FILE__).'/'.$standard.'/Tests/';
             }
@@ -86,6 +85,10 @@ class PHP_CodeSniffer_Standards_AllSniffs
                 continue;
             }
 
+            // Locate the actual directory that contains the standard's tests.
+            // This is individual to each standard as they could be symlinked in.
+            $baseDir = dirname(dirname($standardDir));
+
             $di = new RecursiveIteratorIterator(new RecursiveDirectoryIterator($standardDir));
 
             foreach ($di as $file) {
@@ -94,32 +97,20 @@ class PHP_CodeSniffer_Standards_AllSniffs
                     continue;
                 }
 
-                // Tests must have the extention 'php'.
+                // Tests must have the extension 'php'.
                 $parts = explode('.', $file);
                 $ext   = array_pop($parts);
                 if ($ext !== 'php') {
                     continue;
                 }
 
-                $filePath = realpath($file->getPathname());
-
-                if ($isInstalled === false) {
-                    $className = str_replace($standardDir.DIRECTORY_SEPARATOR, '', $filePath);
-                } else {
-                    $className = str_replace(dirname(__FILE__).DIRECTORY_SEPARATOR, '', $filePath);
-                }
-
+                $filePath  = $file->getPathname();
+                $className = str_replace($baseDir.DIRECTORY_SEPARATOR, '', $filePath);
                 $className = substr($className, 0, -4);
                 $className = str_replace(DIRECTORY_SEPARATOR, '_', $className);
 
-                if ($isInstalled === false) {
-                    $className = $standard.'_Tests_'.$className;
-                }
-
-                $niceName  = substr($className, (strrpos($className, '_') + 1), -8);
-
                 include_once $filePath;
-                $class = new $className($niceName);
+                $class = new $className('getErrorList');
                 $suite->addTest($class);
             }//end foreach
         }//end foreach
